Documentation
¶
Index ¶
- Constants
- Variables
- func AllowRegister(v bool) predicate.Authentication
- func AllowRegisterEQ(v bool) predicate.Authentication
- func AllowRegisterIsNil() predicate.Authentication
- func AllowRegisterNEQ(v bool) predicate.Authentication
- func AllowRegisterNotNil() predicate.Authentication
- func And(predicates ...predicate.Authentication) predicate.Authentication
- func ID(id int) predicate.Authentication
- func IDEQ(id int) predicate.Authentication
- func IDGT(id int) predicate.Authentication
- func IDGTE(id int) predicate.Authentication
- func IDIn(ids ...int) predicate.Authentication
- func IDLT(id int) predicate.Authentication
- func IDLTE(id int) predicate.Authentication
- func IDNEQ(id int) predicate.Authentication
- func IDNotIn(ids ...int) predicate.Authentication
- func Not(p predicate.Authentication) predicate.Authentication
- func OIDCAutoApprove(v bool) predicate.Authentication
- func OIDCAutoApproveEQ(v bool) predicate.Authentication
- func OIDCAutoApproveIsNil() predicate.Authentication
- func OIDCAutoApproveNEQ(v bool) predicate.Authentication
- func OIDCAutoApproveNotNil() predicate.Authentication
- func OIDCAutoCreateAccount(v bool) predicate.Authentication
- func OIDCAutoCreateAccountEQ(v bool) predicate.Authentication
- func OIDCAutoCreateAccountIsNil() predicate.Authentication
- func OIDCAutoCreateAccountNEQ(v bool) predicate.Authentication
- func OIDCAutoCreateAccountNotNil() predicate.Authentication
- func OIDCClientID(v string) predicate.Authentication
- func OIDCClientIDContains(v string) predicate.Authentication
- func OIDCClientIDContainsFold(v string) predicate.Authentication
- func OIDCClientIDEQ(v string) predicate.Authentication
- func OIDCClientIDEqualFold(v string) predicate.Authentication
- func OIDCClientIDGT(v string) predicate.Authentication
- func OIDCClientIDGTE(v string) predicate.Authentication
- func OIDCClientIDHasPrefix(v string) predicate.Authentication
- func OIDCClientIDHasSuffix(v string) predicate.Authentication
- func OIDCClientIDIn(vs ...string) predicate.Authentication
- func OIDCClientIDIsNil() predicate.Authentication
- func OIDCClientIDLT(v string) predicate.Authentication
- func OIDCClientIDLTE(v string) predicate.Authentication
- func OIDCClientIDNEQ(v string) predicate.Authentication
- func OIDCClientIDNotIn(vs ...string) predicate.Authentication
- func OIDCClientIDNotNil() predicate.Authentication
- func OIDCCookieEncriptionKey(v string) predicate.Authentication
- func OIDCCookieEncriptionKeyContains(v string) predicate.Authentication
- func OIDCCookieEncriptionKeyContainsFold(v string) predicate.Authentication
- func OIDCCookieEncriptionKeyEQ(v string) predicate.Authentication
- func OIDCCookieEncriptionKeyEqualFold(v string) predicate.Authentication
- func OIDCCookieEncriptionKeyGT(v string) predicate.Authentication
- func OIDCCookieEncriptionKeyGTE(v string) predicate.Authentication
- func OIDCCookieEncriptionKeyHasPrefix(v string) predicate.Authentication
- func OIDCCookieEncriptionKeyHasSuffix(v string) predicate.Authentication
- func OIDCCookieEncriptionKeyIn(vs ...string) predicate.Authentication
- func OIDCCookieEncriptionKeyIsNil() predicate.Authentication
- func OIDCCookieEncriptionKeyLT(v string) predicate.Authentication
- func OIDCCookieEncriptionKeyLTE(v string) predicate.Authentication
- func OIDCCookieEncriptionKeyNEQ(v string) predicate.Authentication
- func OIDCCookieEncriptionKeyNotIn(vs ...string) predicate.Authentication
- func OIDCCookieEncriptionKeyNotNil() predicate.Authentication
- func OIDCIssuerURL(v string) predicate.Authentication
- func OIDCIssuerURLContains(v string) predicate.Authentication
- func OIDCIssuerURLContainsFold(v string) predicate.Authentication
- func OIDCIssuerURLEQ(v string) predicate.Authentication
- func OIDCIssuerURLEqualFold(v string) predicate.Authentication
- func OIDCIssuerURLGT(v string) predicate.Authentication
- func OIDCIssuerURLGTE(v string) predicate.Authentication
- func OIDCIssuerURLHasPrefix(v string) predicate.Authentication
- func OIDCIssuerURLHasSuffix(v string) predicate.Authentication
- func OIDCIssuerURLIn(vs ...string) predicate.Authentication
- func OIDCIssuerURLIsNil() predicate.Authentication
- func OIDCIssuerURLLT(v string) predicate.Authentication
- func OIDCIssuerURLLTE(v string) predicate.Authentication
- func OIDCIssuerURLNEQ(v string) predicate.Authentication
- func OIDCIssuerURLNotIn(vs ...string) predicate.Authentication
- func OIDCIssuerURLNotNil() predicate.Authentication
- func OIDCKeycloakPublicKey(v string) predicate.Authentication
- func OIDCKeycloakPublicKeyContains(v string) predicate.Authentication
- func OIDCKeycloakPublicKeyContainsFold(v string) predicate.Authentication
- func OIDCKeycloakPublicKeyEQ(v string) predicate.Authentication
- func OIDCKeycloakPublicKeyEqualFold(v string) predicate.Authentication
- func OIDCKeycloakPublicKeyGT(v string) predicate.Authentication
- func OIDCKeycloakPublicKeyGTE(v string) predicate.Authentication
- func OIDCKeycloakPublicKeyHasPrefix(v string) predicate.Authentication
- func OIDCKeycloakPublicKeyHasSuffix(v string) predicate.Authentication
- func OIDCKeycloakPublicKeyIn(vs ...string) predicate.Authentication
- func OIDCKeycloakPublicKeyIsNil() predicate.Authentication
- func OIDCKeycloakPublicKeyLT(v string) predicate.Authentication
- func OIDCKeycloakPublicKeyLTE(v string) predicate.Authentication
- func OIDCKeycloakPublicKeyNEQ(v string) predicate.Authentication
- func OIDCKeycloakPublicKeyNotIn(vs ...string) predicate.Authentication
- func OIDCKeycloakPublicKeyNotNil() predicate.Authentication
- func OIDCProvider(v string) predicate.Authentication
- func OIDCProviderContains(v string) predicate.Authentication
- func OIDCProviderContainsFold(v string) predicate.Authentication
- func OIDCProviderEQ(v string) predicate.Authentication
- func OIDCProviderEqualFold(v string) predicate.Authentication
- func OIDCProviderGT(v string) predicate.Authentication
- func OIDCProviderGTE(v string) predicate.Authentication
- func OIDCProviderHasPrefix(v string) predicate.Authentication
- func OIDCProviderHasSuffix(v string) predicate.Authentication
- func OIDCProviderIn(vs ...string) predicate.Authentication
- func OIDCProviderIsNil() predicate.Authentication
- func OIDCProviderLT(v string) predicate.Authentication
- func OIDCProviderLTE(v string) predicate.Authentication
- func OIDCProviderNEQ(v string) predicate.Authentication
- func OIDCProviderNotIn(vs ...string) predicate.Authentication
- func OIDCProviderNotNil() predicate.Authentication
- func OIDCRoleAdmin(v string) predicate.Authentication
- func OIDCRoleAdminContains(v string) predicate.Authentication
- func OIDCRoleAdminContainsFold(v string) predicate.Authentication
- func OIDCRoleAdminEQ(v string) predicate.Authentication
- func OIDCRoleAdminEqualFold(v string) predicate.Authentication
- func OIDCRoleAdminGT(v string) predicate.Authentication
- func OIDCRoleAdminGTE(v string) predicate.Authentication
- func OIDCRoleAdminHasPrefix(v string) predicate.Authentication
- func OIDCRoleAdminHasSuffix(v string) predicate.Authentication
- func OIDCRoleAdminIn(vs ...string) predicate.Authentication
- func OIDCRoleAdminIsNil() predicate.Authentication
- func OIDCRoleAdminLT(v string) predicate.Authentication
- func OIDCRoleAdminLTE(v string) predicate.Authentication
- func OIDCRoleAdminNEQ(v string) predicate.Authentication
- func OIDCRoleAdminNotIn(vs ...string) predicate.Authentication
- func OIDCRoleAdminNotNil() predicate.Authentication
- func OIDCRoleOperator(v string) predicate.Authentication
- func OIDCRoleOperatorContains(v string) predicate.Authentication
- func OIDCRoleOperatorContainsFold(v string) predicate.Authentication
- func OIDCRoleOperatorEQ(v string) predicate.Authentication
- func OIDCRoleOperatorEqualFold(v string) predicate.Authentication
- func OIDCRoleOperatorGT(v string) predicate.Authentication
- func OIDCRoleOperatorGTE(v string) predicate.Authentication
- func OIDCRoleOperatorHasPrefix(v string) predicate.Authentication
- func OIDCRoleOperatorHasSuffix(v string) predicate.Authentication
- func OIDCRoleOperatorIn(vs ...string) predicate.Authentication
- func OIDCRoleOperatorIsNil() predicate.Authentication
- func OIDCRoleOperatorLT(v string) predicate.Authentication
- func OIDCRoleOperatorLTE(v string) predicate.Authentication
- func OIDCRoleOperatorNEQ(v string) predicate.Authentication
- func OIDCRoleOperatorNotIn(vs ...string) predicate.Authentication
- func OIDCRoleOperatorNotNil() predicate.Authentication
- func OIDCRoleUser(v string) predicate.Authentication
- func OIDCRoleUserContains(v string) predicate.Authentication
- func OIDCRoleUserContainsFold(v string) predicate.Authentication
- func OIDCRoleUserEQ(v string) predicate.Authentication
- func OIDCRoleUserEqualFold(v string) predicate.Authentication
- func OIDCRoleUserGT(v string) predicate.Authentication
- func OIDCRoleUserGTE(v string) predicate.Authentication
- func OIDCRoleUserHasPrefix(v string) predicate.Authentication
- func OIDCRoleUserHasSuffix(v string) predicate.Authentication
- func OIDCRoleUserIn(vs ...string) predicate.Authentication
- func OIDCRoleUserIsNil() predicate.Authentication
- func OIDCRoleUserLT(v string) predicate.Authentication
- func OIDCRoleUserLTE(v string) predicate.Authentication
- func OIDCRoleUserNEQ(v string) predicate.Authentication
- func OIDCRoleUserNotIn(vs ...string) predicate.Authentication
- func OIDCRoleUserNotNil() predicate.Authentication
- func Or(predicates ...predicate.Authentication) predicate.Authentication
- func UseCertificates(v bool) predicate.Authentication
- func UseCertificatesEQ(v bool) predicate.Authentication
- func UseCertificatesIsNil() predicate.Authentication
- func UseCertificatesNEQ(v bool) predicate.Authentication
- func UseCertificatesNotNil() predicate.Authentication
- func UseOIDC(v bool) predicate.Authentication
- func UseOIDCEQ(v bool) predicate.Authentication
- func UseOIDCIsNil() predicate.Authentication
- func UseOIDCNEQ(v bool) predicate.Authentication
- func UseOIDCNotNil() predicate.Authentication
- func UsePasswd(v bool) predicate.Authentication
- func UsePasswdEQ(v bool) predicate.Authentication
- func UsePasswdIsNil() predicate.Authentication
- func UsePasswdNEQ(v bool) predicate.Authentication
- func UsePasswdNotNil() predicate.Authentication
- func ValidColumn(column string) bool
- type OrderOption
- func ByAllowRegister(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByOIDCAutoApprove(opts ...sql.OrderTermOption) OrderOption
- func ByOIDCAutoCreateAccount(opts ...sql.OrderTermOption) OrderOption
- func ByOIDCClientID(opts ...sql.OrderTermOption) OrderOption
- func ByOIDCCookieEncriptionKey(opts ...sql.OrderTermOption) OrderOption
- func ByOIDCIssuerURL(opts ...sql.OrderTermOption) OrderOption
- func ByOIDCKeycloakPublicKey(opts ...sql.OrderTermOption) OrderOption
- func ByOIDCProvider(opts ...sql.OrderTermOption) OrderOption
- func ByOIDCRoleAdmin(opts ...sql.OrderTermOption) OrderOption
- func ByOIDCRoleOperator(opts ...sql.OrderTermOption) OrderOption
- func ByOIDCRoleUser(opts ...sql.OrderTermOption) OrderOption
- func ByUseCertificates(opts ...sql.OrderTermOption) OrderOption
- func ByUseOIDC(opts ...sql.OrderTermOption) OrderOption
- func ByUsePasswd(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the authentication type in the database. Label = "authentication" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldUseCertificates holds the string denoting the use_certificates field in the database. FieldUseCertificates = "use_certificates" // FieldAllowRegister holds the string denoting the allow_register field in the database. FieldAllowRegister = "allow_register" // FieldUseOIDC holds the string denoting the use_oidc field in the database. FieldUseOIDC = "use_oidc" // FieldOIDCProvider holds the string denoting the oidc_provider field in the database. FieldOIDCProvider = "oidc_provider" // FieldOIDCIssuerURL holds the string denoting the oidc_issuer_url field in the database. FieldOIDCIssuerURL = "oidc_issuer_url" // FieldOIDCClientID holds the string denoting the oidc_client_id field in the database. FieldOIDCClientID = "oidc_client_id" // FieldOIDCRoleAdmin holds the string denoting the oidc_role_admin field in the database. FieldOIDCRoleAdmin = "oidc_role_admin" // FieldOIDCRoleOperator holds the string denoting the oidc_role_operator field in the database. FieldOIDCRoleOperator = "oidc_role_operator" // FieldOIDCRoleUser holds the string denoting the oidc_role_user field in the database. FieldOIDCRoleUser = "oidc_role_user" // FieldOIDCCookieEncriptionKey holds the string denoting the oidc_cookie_encription_key field in the database. FieldOIDCCookieEncriptionKey = "oidc_cookie_encription_key" // FieldOIDCKeycloakPublicKey holds the string denoting the oidc_keycloak_public_key field in the database. FieldOIDCKeycloakPublicKey = "oidc_keycloak_public_key" // FieldOIDCAutoCreateAccount holds the string denoting the oidc_auto_create_account field in the database. FieldOIDCAutoCreateAccount = "oidc_auto_create_account" // FieldOIDCAutoApprove holds the string denoting the oidc_auto_approve field in the database. FieldOIDCAutoApprove = "oidc_auto_approve" // FieldUsePasswd holds the string denoting the use_passwd field in the database. FieldUsePasswd = "use_passwd" // Table holds the table name of the authentication in the database. Table = "authentications" )
Variables ¶
var ( // DefaultUseCertificates holds the default value on creation for the "use_certificates" field. DefaultUseCertificates bool // DefaultAllowRegister holds the default value on creation for the "allow_register" field. DefaultAllowRegister bool // DefaultUseOIDC holds the default value on creation for the "use_OIDC" field. DefaultUseOIDC bool // DefaultOIDCProvider holds the default value on creation for the "OIDC_provider" field. DefaultOIDCProvider string // DefaultOIDCIssuerURL holds the default value on creation for the "OIDC_issuer_url" field. DefaultOIDCIssuerURL string // DefaultOIDCClientID holds the default value on creation for the "OIDC_client_id" field. DefaultOIDCClientID string // DefaultOIDCRoleAdmin holds the default value on creation for the "OIDC_role_admin" field. DefaultOIDCRoleAdmin string // DefaultOIDCRoleOperator holds the default value on creation for the "OIDC_role_operator" field. DefaultOIDCRoleOperator string // DefaultOIDCRoleUser holds the default value on creation for the "OIDC_role_user" field. DefaultOIDCRoleUser string // DefaultOIDCCookieEncriptionKey holds the default value on creation for the "OIDC_cookie_encription_key" field. DefaultOIDCCookieEncriptionKey string // DefaultOIDCKeycloakPublicKey holds the default value on creation for the "OIDC_keycloak_public_key" field. DefaultOIDCKeycloakPublicKey string // DefaultOIDCAutoCreateAccount holds the default value on creation for the "OIDC_auto_create_account" field. DefaultOIDCAutoCreateAccount bool // DefaultOIDCAutoApprove holds the default value on creation for the "OIDC_auto_approve" field. DefaultOIDCAutoApprove bool // DefaultUsePasswd holds the default value on creation for the "use_passwd" field. DefaultUsePasswd bool )
var Columns = []string{ FieldID, FieldUseCertificates, FieldAllowRegister, FieldUseOIDC, FieldOIDCProvider, FieldOIDCIssuerURL, FieldOIDCClientID, FieldOIDCRoleAdmin, FieldOIDCRoleOperator, FieldOIDCRoleUser, FieldOIDCCookieEncriptionKey, FieldOIDCKeycloakPublicKey, FieldOIDCAutoCreateAccount, FieldOIDCAutoApprove, FieldUsePasswd, }
Columns holds all SQL columns for authentication fields.
Functions ¶
func AllowRegister ¶
func AllowRegister(v bool) predicate.Authentication
AllowRegister applies equality check predicate on the "allow_register" field. It's identical to AllowRegisterEQ.
func AllowRegisterEQ ¶
func AllowRegisterEQ(v bool) predicate.Authentication
AllowRegisterEQ applies the EQ predicate on the "allow_register" field.
func AllowRegisterIsNil ¶
func AllowRegisterIsNil() predicate.Authentication
AllowRegisterIsNil applies the IsNil predicate on the "allow_register" field.
func AllowRegisterNEQ ¶
func AllowRegisterNEQ(v bool) predicate.Authentication
AllowRegisterNEQ applies the NEQ predicate on the "allow_register" field.
func AllowRegisterNotNil ¶
func AllowRegisterNotNil() predicate.Authentication
AllowRegisterNotNil applies the NotNil predicate on the "allow_register" field.
func And ¶
func And(predicates ...predicate.Authentication) predicate.Authentication
And groups predicates with the AND operator between them.
func IDEQ ¶
func IDEQ(id int) predicate.Authentication
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id int) predicate.Authentication
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id int) predicate.Authentication
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.Authentication
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id int) predicate.Authentication
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.Authentication
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.Authentication
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.Authentication
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.Authentication) predicate.Authentication
Not applies the not operator on the given predicate.
func OIDCAutoApprove ¶
func OIDCAutoApprove(v bool) predicate.Authentication
OIDCAutoApprove applies equality check predicate on the "OIDC_auto_approve" field. It's identical to OIDCAutoApproveEQ.
func OIDCAutoApproveEQ ¶
func OIDCAutoApproveEQ(v bool) predicate.Authentication
OIDCAutoApproveEQ applies the EQ predicate on the "OIDC_auto_approve" field.
func OIDCAutoApproveIsNil ¶
func OIDCAutoApproveIsNil() predicate.Authentication
OIDCAutoApproveIsNil applies the IsNil predicate on the "OIDC_auto_approve" field.
func OIDCAutoApproveNEQ ¶
func OIDCAutoApproveNEQ(v bool) predicate.Authentication
OIDCAutoApproveNEQ applies the NEQ predicate on the "OIDC_auto_approve" field.
func OIDCAutoApproveNotNil ¶
func OIDCAutoApproveNotNil() predicate.Authentication
OIDCAutoApproveNotNil applies the NotNil predicate on the "OIDC_auto_approve" field.
func OIDCAutoCreateAccount ¶
func OIDCAutoCreateAccount(v bool) predicate.Authentication
OIDCAutoCreateAccount applies equality check predicate on the "OIDC_auto_create_account" field. It's identical to OIDCAutoCreateAccountEQ.
func OIDCAutoCreateAccountEQ ¶
func OIDCAutoCreateAccountEQ(v bool) predicate.Authentication
OIDCAutoCreateAccountEQ applies the EQ predicate on the "OIDC_auto_create_account" field.
func OIDCAutoCreateAccountIsNil ¶
func OIDCAutoCreateAccountIsNil() predicate.Authentication
OIDCAutoCreateAccountIsNil applies the IsNil predicate on the "OIDC_auto_create_account" field.
func OIDCAutoCreateAccountNEQ ¶
func OIDCAutoCreateAccountNEQ(v bool) predicate.Authentication
OIDCAutoCreateAccountNEQ applies the NEQ predicate on the "OIDC_auto_create_account" field.
func OIDCAutoCreateAccountNotNil ¶
func OIDCAutoCreateAccountNotNil() predicate.Authentication
OIDCAutoCreateAccountNotNil applies the NotNil predicate on the "OIDC_auto_create_account" field.
func OIDCClientID ¶
func OIDCClientID(v string) predicate.Authentication
OIDCClientID applies equality check predicate on the "OIDC_client_id" field. It's identical to OIDCClientIDEQ.
func OIDCClientIDContains ¶
func OIDCClientIDContains(v string) predicate.Authentication
OIDCClientIDContains applies the Contains predicate on the "OIDC_client_id" field.
func OIDCClientIDContainsFold ¶
func OIDCClientIDContainsFold(v string) predicate.Authentication
OIDCClientIDContainsFold applies the ContainsFold predicate on the "OIDC_client_id" field.
func OIDCClientIDEQ ¶
func OIDCClientIDEQ(v string) predicate.Authentication
OIDCClientIDEQ applies the EQ predicate on the "OIDC_client_id" field.
func OIDCClientIDEqualFold ¶
func OIDCClientIDEqualFold(v string) predicate.Authentication
OIDCClientIDEqualFold applies the EqualFold predicate on the "OIDC_client_id" field.
func OIDCClientIDGT ¶
func OIDCClientIDGT(v string) predicate.Authentication
OIDCClientIDGT applies the GT predicate on the "OIDC_client_id" field.
func OIDCClientIDGTE ¶
func OIDCClientIDGTE(v string) predicate.Authentication
OIDCClientIDGTE applies the GTE predicate on the "OIDC_client_id" field.
func OIDCClientIDHasPrefix ¶
func OIDCClientIDHasPrefix(v string) predicate.Authentication
OIDCClientIDHasPrefix applies the HasPrefix predicate on the "OIDC_client_id" field.
func OIDCClientIDHasSuffix ¶
func OIDCClientIDHasSuffix(v string) predicate.Authentication
OIDCClientIDHasSuffix applies the HasSuffix predicate on the "OIDC_client_id" field.
func OIDCClientIDIn ¶
func OIDCClientIDIn(vs ...string) predicate.Authentication
OIDCClientIDIn applies the In predicate on the "OIDC_client_id" field.
func OIDCClientIDIsNil ¶
func OIDCClientIDIsNil() predicate.Authentication
OIDCClientIDIsNil applies the IsNil predicate on the "OIDC_client_id" field.
func OIDCClientIDLT ¶
func OIDCClientIDLT(v string) predicate.Authentication
OIDCClientIDLT applies the LT predicate on the "OIDC_client_id" field.
func OIDCClientIDLTE ¶
func OIDCClientIDLTE(v string) predicate.Authentication
OIDCClientIDLTE applies the LTE predicate on the "OIDC_client_id" field.
func OIDCClientIDNEQ ¶
func OIDCClientIDNEQ(v string) predicate.Authentication
OIDCClientIDNEQ applies the NEQ predicate on the "OIDC_client_id" field.
func OIDCClientIDNotIn ¶
func OIDCClientIDNotIn(vs ...string) predicate.Authentication
OIDCClientIDNotIn applies the NotIn predicate on the "OIDC_client_id" field.
func OIDCClientIDNotNil ¶
func OIDCClientIDNotNil() predicate.Authentication
OIDCClientIDNotNil applies the NotNil predicate on the "OIDC_client_id" field.
func OIDCCookieEncriptionKey ¶
func OIDCCookieEncriptionKey(v string) predicate.Authentication
OIDCCookieEncriptionKey applies equality check predicate on the "OIDC_cookie_encription_key" field. It's identical to OIDCCookieEncriptionKeyEQ.
func OIDCCookieEncriptionKeyContains ¶
func OIDCCookieEncriptionKeyContains(v string) predicate.Authentication
OIDCCookieEncriptionKeyContains applies the Contains predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyContainsFold ¶
func OIDCCookieEncriptionKeyContainsFold(v string) predicate.Authentication
OIDCCookieEncriptionKeyContainsFold applies the ContainsFold predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyEQ ¶
func OIDCCookieEncriptionKeyEQ(v string) predicate.Authentication
OIDCCookieEncriptionKeyEQ applies the EQ predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyEqualFold ¶
func OIDCCookieEncriptionKeyEqualFold(v string) predicate.Authentication
OIDCCookieEncriptionKeyEqualFold applies the EqualFold predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyGT ¶
func OIDCCookieEncriptionKeyGT(v string) predicate.Authentication
OIDCCookieEncriptionKeyGT applies the GT predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyGTE ¶
func OIDCCookieEncriptionKeyGTE(v string) predicate.Authentication
OIDCCookieEncriptionKeyGTE applies the GTE predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyHasPrefix ¶
func OIDCCookieEncriptionKeyHasPrefix(v string) predicate.Authentication
OIDCCookieEncriptionKeyHasPrefix applies the HasPrefix predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyHasSuffix ¶
func OIDCCookieEncriptionKeyHasSuffix(v string) predicate.Authentication
OIDCCookieEncriptionKeyHasSuffix applies the HasSuffix predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyIn ¶
func OIDCCookieEncriptionKeyIn(vs ...string) predicate.Authentication
OIDCCookieEncriptionKeyIn applies the In predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyIsNil ¶
func OIDCCookieEncriptionKeyIsNil() predicate.Authentication
OIDCCookieEncriptionKeyIsNil applies the IsNil predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyLT ¶
func OIDCCookieEncriptionKeyLT(v string) predicate.Authentication
OIDCCookieEncriptionKeyLT applies the LT predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyLTE ¶
func OIDCCookieEncriptionKeyLTE(v string) predicate.Authentication
OIDCCookieEncriptionKeyLTE applies the LTE predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyNEQ ¶
func OIDCCookieEncriptionKeyNEQ(v string) predicate.Authentication
OIDCCookieEncriptionKeyNEQ applies the NEQ predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyNotIn ¶
func OIDCCookieEncriptionKeyNotIn(vs ...string) predicate.Authentication
OIDCCookieEncriptionKeyNotIn applies the NotIn predicate on the "OIDC_cookie_encription_key" field.
func OIDCCookieEncriptionKeyNotNil ¶
func OIDCCookieEncriptionKeyNotNil() predicate.Authentication
OIDCCookieEncriptionKeyNotNil applies the NotNil predicate on the "OIDC_cookie_encription_key" field.
func OIDCIssuerURL ¶
func OIDCIssuerURL(v string) predicate.Authentication
OIDCIssuerURL applies equality check predicate on the "OIDC_issuer_url" field. It's identical to OIDCIssuerURLEQ.
func OIDCIssuerURLContains ¶
func OIDCIssuerURLContains(v string) predicate.Authentication
OIDCIssuerURLContains applies the Contains predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLContainsFold ¶
func OIDCIssuerURLContainsFold(v string) predicate.Authentication
OIDCIssuerURLContainsFold applies the ContainsFold predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLEQ ¶
func OIDCIssuerURLEQ(v string) predicate.Authentication
OIDCIssuerURLEQ applies the EQ predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLEqualFold ¶
func OIDCIssuerURLEqualFold(v string) predicate.Authentication
OIDCIssuerURLEqualFold applies the EqualFold predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLGT ¶
func OIDCIssuerURLGT(v string) predicate.Authentication
OIDCIssuerURLGT applies the GT predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLGTE ¶
func OIDCIssuerURLGTE(v string) predicate.Authentication
OIDCIssuerURLGTE applies the GTE predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLHasPrefix ¶
func OIDCIssuerURLHasPrefix(v string) predicate.Authentication
OIDCIssuerURLHasPrefix applies the HasPrefix predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLHasSuffix ¶
func OIDCIssuerURLHasSuffix(v string) predicate.Authentication
OIDCIssuerURLHasSuffix applies the HasSuffix predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLIn ¶
func OIDCIssuerURLIn(vs ...string) predicate.Authentication
OIDCIssuerURLIn applies the In predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLIsNil ¶
func OIDCIssuerURLIsNil() predicate.Authentication
OIDCIssuerURLIsNil applies the IsNil predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLLT ¶
func OIDCIssuerURLLT(v string) predicate.Authentication
OIDCIssuerURLLT applies the LT predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLLTE ¶
func OIDCIssuerURLLTE(v string) predicate.Authentication
OIDCIssuerURLLTE applies the LTE predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLNEQ ¶
func OIDCIssuerURLNEQ(v string) predicate.Authentication
OIDCIssuerURLNEQ applies the NEQ predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLNotIn ¶
func OIDCIssuerURLNotIn(vs ...string) predicate.Authentication
OIDCIssuerURLNotIn applies the NotIn predicate on the "OIDC_issuer_url" field.
func OIDCIssuerURLNotNil ¶
func OIDCIssuerURLNotNil() predicate.Authentication
OIDCIssuerURLNotNil applies the NotNil predicate on the "OIDC_issuer_url" field.
func OIDCKeycloakPublicKey ¶
func OIDCKeycloakPublicKey(v string) predicate.Authentication
OIDCKeycloakPublicKey applies equality check predicate on the "OIDC_keycloak_public_key" field. It's identical to OIDCKeycloakPublicKeyEQ.
func OIDCKeycloakPublicKeyContains ¶
func OIDCKeycloakPublicKeyContains(v string) predicate.Authentication
OIDCKeycloakPublicKeyContains applies the Contains predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyContainsFold ¶
func OIDCKeycloakPublicKeyContainsFold(v string) predicate.Authentication
OIDCKeycloakPublicKeyContainsFold applies the ContainsFold predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyEQ ¶
func OIDCKeycloakPublicKeyEQ(v string) predicate.Authentication
OIDCKeycloakPublicKeyEQ applies the EQ predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyEqualFold ¶
func OIDCKeycloakPublicKeyEqualFold(v string) predicate.Authentication
OIDCKeycloakPublicKeyEqualFold applies the EqualFold predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyGT ¶
func OIDCKeycloakPublicKeyGT(v string) predicate.Authentication
OIDCKeycloakPublicKeyGT applies the GT predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyGTE ¶
func OIDCKeycloakPublicKeyGTE(v string) predicate.Authentication
OIDCKeycloakPublicKeyGTE applies the GTE predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyHasPrefix ¶
func OIDCKeycloakPublicKeyHasPrefix(v string) predicate.Authentication
OIDCKeycloakPublicKeyHasPrefix applies the HasPrefix predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyHasSuffix ¶
func OIDCKeycloakPublicKeyHasSuffix(v string) predicate.Authentication
OIDCKeycloakPublicKeyHasSuffix applies the HasSuffix predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyIn ¶
func OIDCKeycloakPublicKeyIn(vs ...string) predicate.Authentication
OIDCKeycloakPublicKeyIn applies the In predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyIsNil ¶
func OIDCKeycloakPublicKeyIsNil() predicate.Authentication
OIDCKeycloakPublicKeyIsNil applies the IsNil predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyLT ¶
func OIDCKeycloakPublicKeyLT(v string) predicate.Authentication
OIDCKeycloakPublicKeyLT applies the LT predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyLTE ¶
func OIDCKeycloakPublicKeyLTE(v string) predicate.Authentication
OIDCKeycloakPublicKeyLTE applies the LTE predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyNEQ ¶
func OIDCKeycloakPublicKeyNEQ(v string) predicate.Authentication
OIDCKeycloakPublicKeyNEQ applies the NEQ predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyNotIn ¶
func OIDCKeycloakPublicKeyNotIn(vs ...string) predicate.Authentication
OIDCKeycloakPublicKeyNotIn applies the NotIn predicate on the "OIDC_keycloak_public_key" field.
func OIDCKeycloakPublicKeyNotNil ¶
func OIDCKeycloakPublicKeyNotNil() predicate.Authentication
OIDCKeycloakPublicKeyNotNil applies the NotNil predicate on the "OIDC_keycloak_public_key" field.
func OIDCProvider ¶
func OIDCProvider(v string) predicate.Authentication
OIDCProvider applies equality check predicate on the "OIDC_provider" field. It's identical to OIDCProviderEQ.
func OIDCProviderContains ¶
func OIDCProviderContains(v string) predicate.Authentication
OIDCProviderContains applies the Contains predicate on the "OIDC_provider" field.
func OIDCProviderContainsFold ¶
func OIDCProviderContainsFold(v string) predicate.Authentication
OIDCProviderContainsFold applies the ContainsFold predicate on the "OIDC_provider" field.
func OIDCProviderEQ ¶
func OIDCProviderEQ(v string) predicate.Authentication
OIDCProviderEQ applies the EQ predicate on the "OIDC_provider" field.
func OIDCProviderEqualFold ¶
func OIDCProviderEqualFold(v string) predicate.Authentication
OIDCProviderEqualFold applies the EqualFold predicate on the "OIDC_provider" field.
func OIDCProviderGT ¶
func OIDCProviderGT(v string) predicate.Authentication
OIDCProviderGT applies the GT predicate on the "OIDC_provider" field.
func OIDCProviderGTE ¶
func OIDCProviderGTE(v string) predicate.Authentication
OIDCProviderGTE applies the GTE predicate on the "OIDC_provider" field.
func OIDCProviderHasPrefix ¶
func OIDCProviderHasPrefix(v string) predicate.Authentication
OIDCProviderHasPrefix applies the HasPrefix predicate on the "OIDC_provider" field.
func OIDCProviderHasSuffix ¶
func OIDCProviderHasSuffix(v string) predicate.Authentication
OIDCProviderHasSuffix applies the HasSuffix predicate on the "OIDC_provider" field.
func OIDCProviderIn ¶
func OIDCProviderIn(vs ...string) predicate.Authentication
OIDCProviderIn applies the In predicate on the "OIDC_provider" field.
func OIDCProviderIsNil ¶
func OIDCProviderIsNil() predicate.Authentication
OIDCProviderIsNil applies the IsNil predicate on the "OIDC_provider" field.
func OIDCProviderLT ¶
func OIDCProviderLT(v string) predicate.Authentication
OIDCProviderLT applies the LT predicate on the "OIDC_provider" field.
func OIDCProviderLTE ¶
func OIDCProviderLTE(v string) predicate.Authentication
OIDCProviderLTE applies the LTE predicate on the "OIDC_provider" field.
func OIDCProviderNEQ ¶
func OIDCProviderNEQ(v string) predicate.Authentication
OIDCProviderNEQ applies the NEQ predicate on the "OIDC_provider" field.
func OIDCProviderNotIn ¶
func OIDCProviderNotIn(vs ...string) predicate.Authentication
OIDCProviderNotIn applies the NotIn predicate on the "OIDC_provider" field.
func OIDCProviderNotNil ¶
func OIDCProviderNotNil() predicate.Authentication
OIDCProviderNotNil applies the NotNil predicate on the "OIDC_provider" field.
func OIDCRoleAdmin ¶
func OIDCRoleAdmin(v string) predicate.Authentication
OIDCRoleAdmin applies equality check predicate on the "OIDC_role_admin" field. It's identical to OIDCRoleAdminEQ.
func OIDCRoleAdminContains ¶
func OIDCRoleAdminContains(v string) predicate.Authentication
OIDCRoleAdminContains applies the Contains predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminContainsFold ¶
func OIDCRoleAdminContainsFold(v string) predicate.Authentication
OIDCRoleAdminContainsFold applies the ContainsFold predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminEQ ¶
func OIDCRoleAdminEQ(v string) predicate.Authentication
OIDCRoleAdminEQ applies the EQ predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminEqualFold ¶
func OIDCRoleAdminEqualFold(v string) predicate.Authentication
OIDCRoleAdminEqualFold applies the EqualFold predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminGT ¶
func OIDCRoleAdminGT(v string) predicate.Authentication
OIDCRoleAdminGT applies the GT predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminGTE ¶
func OIDCRoleAdminGTE(v string) predicate.Authentication
OIDCRoleAdminGTE applies the GTE predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminHasPrefix ¶
func OIDCRoleAdminHasPrefix(v string) predicate.Authentication
OIDCRoleAdminHasPrefix applies the HasPrefix predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminHasSuffix ¶
func OIDCRoleAdminHasSuffix(v string) predicate.Authentication
OIDCRoleAdminHasSuffix applies the HasSuffix predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminIn ¶
func OIDCRoleAdminIn(vs ...string) predicate.Authentication
OIDCRoleAdminIn applies the In predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminIsNil ¶
func OIDCRoleAdminIsNil() predicate.Authentication
OIDCRoleAdminIsNil applies the IsNil predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminLT ¶
func OIDCRoleAdminLT(v string) predicate.Authentication
OIDCRoleAdminLT applies the LT predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminLTE ¶
func OIDCRoleAdminLTE(v string) predicate.Authentication
OIDCRoleAdminLTE applies the LTE predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminNEQ ¶
func OIDCRoleAdminNEQ(v string) predicate.Authentication
OIDCRoleAdminNEQ applies the NEQ predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminNotIn ¶
func OIDCRoleAdminNotIn(vs ...string) predicate.Authentication
OIDCRoleAdminNotIn applies the NotIn predicate on the "OIDC_role_admin" field.
func OIDCRoleAdminNotNil ¶
func OIDCRoleAdminNotNil() predicate.Authentication
OIDCRoleAdminNotNil applies the NotNil predicate on the "OIDC_role_admin" field.
func OIDCRoleOperator ¶
func OIDCRoleOperator(v string) predicate.Authentication
OIDCRoleOperator applies equality check predicate on the "OIDC_role_operator" field. It's identical to OIDCRoleOperatorEQ.
func OIDCRoleOperatorContains ¶
func OIDCRoleOperatorContains(v string) predicate.Authentication
OIDCRoleOperatorContains applies the Contains predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorContainsFold ¶
func OIDCRoleOperatorContainsFold(v string) predicate.Authentication
OIDCRoleOperatorContainsFold applies the ContainsFold predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorEQ ¶
func OIDCRoleOperatorEQ(v string) predicate.Authentication
OIDCRoleOperatorEQ applies the EQ predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorEqualFold ¶
func OIDCRoleOperatorEqualFold(v string) predicate.Authentication
OIDCRoleOperatorEqualFold applies the EqualFold predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorGT ¶
func OIDCRoleOperatorGT(v string) predicate.Authentication
OIDCRoleOperatorGT applies the GT predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorGTE ¶
func OIDCRoleOperatorGTE(v string) predicate.Authentication
OIDCRoleOperatorGTE applies the GTE predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorHasPrefix ¶
func OIDCRoleOperatorHasPrefix(v string) predicate.Authentication
OIDCRoleOperatorHasPrefix applies the HasPrefix predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorHasSuffix ¶
func OIDCRoleOperatorHasSuffix(v string) predicate.Authentication
OIDCRoleOperatorHasSuffix applies the HasSuffix predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorIn ¶
func OIDCRoleOperatorIn(vs ...string) predicate.Authentication
OIDCRoleOperatorIn applies the In predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorIsNil ¶
func OIDCRoleOperatorIsNil() predicate.Authentication
OIDCRoleOperatorIsNil applies the IsNil predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorLT ¶
func OIDCRoleOperatorLT(v string) predicate.Authentication
OIDCRoleOperatorLT applies the LT predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorLTE ¶
func OIDCRoleOperatorLTE(v string) predicate.Authentication
OIDCRoleOperatorLTE applies the LTE predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorNEQ ¶
func OIDCRoleOperatorNEQ(v string) predicate.Authentication
OIDCRoleOperatorNEQ applies the NEQ predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorNotIn ¶
func OIDCRoleOperatorNotIn(vs ...string) predicate.Authentication
OIDCRoleOperatorNotIn applies the NotIn predicate on the "OIDC_role_operator" field.
func OIDCRoleOperatorNotNil ¶
func OIDCRoleOperatorNotNil() predicate.Authentication
OIDCRoleOperatorNotNil applies the NotNil predicate on the "OIDC_role_operator" field.
func OIDCRoleUser ¶
func OIDCRoleUser(v string) predicate.Authentication
OIDCRoleUser applies equality check predicate on the "OIDC_role_user" field. It's identical to OIDCRoleUserEQ.
func OIDCRoleUserContains ¶
func OIDCRoleUserContains(v string) predicate.Authentication
OIDCRoleUserContains applies the Contains predicate on the "OIDC_role_user" field.
func OIDCRoleUserContainsFold ¶
func OIDCRoleUserContainsFold(v string) predicate.Authentication
OIDCRoleUserContainsFold applies the ContainsFold predicate on the "OIDC_role_user" field.
func OIDCRoleUserEQ ¶
func OIDCRoleUserEQ(v string) predicate.Authentication
OIDCRoleUserEQ applies the EQ predicate on the "OIDC_role_user" field.
func OIDCRoleUserEqualFold ¶
func OIDCRoleUserEqualFold(v string) predicate.Authentication
OIDCRoleUserEqualFold applies the EqualFold predicate on the "OIDC_role_user" field.
func OIDCRoleUserGT ¶
func OIDCRoleUserGT(v string) predicate.Authentication
OIDCRoleUserGT applies the GT predicate on the "OIDC_role_user" field.
func OIDCRoleUserGTE ¶
func OIDCRoleUserGTE(v string) predicate.Authentication
OIDCRoleUserGTE applies the GTE predicate on the "OIDC_role_user" field.
func OIDCRoleUserHasPrefix ¶
func OIDCRoleUserHasPrefix(v string) predicate.Authentication
OIDCRoleUserHasPrefix applies the HasPrefix predicate on the "OIDC_role_user" field.
func OIDCRoleUserHasSuffix ¶
func OIDCRoleUserHasSuffix(v string) predicate.Authentication
OIDCRoleUserHasSuffix applies the HasSuffix predicate on the "OIDC_role_user" field.
func OIDCRoleUserIn ¶
func OIDCRoleUserIn(vs ...string) predicate.Authentication
OIDCRoleUserIn applies the In predicate on the "OIDC_role_user" field.
func OIDCRoleUserIsNil ¶
func OIDCRoleUserIsNil() predicate.Authentication
OIDCRoleUserIsNil applies the IsNil predicate on the "OIDC_role_user" field.
func OIDCRoleUserLT ¶
func OIDCRoleUserLT(v string) predicate.Authentication
OIDCRoleUserLT applies the LT predicate on the "OIDC_role_user" field.
func OIDCRoleUserLTE ¶
func OIDCRoleUserLTE(v string) predicate.Authentication
OIDCRoleUserLTE applies the LTE predicate on the "OIDC_role_user" field.
func OIDCRoleUserNEQ ¶
func OIDCRoleUserNEQ(v string) predicate.Authentication
OIDCRoleUserNEQ applies the NEQ predicate on the "OIDC_role_user" field.
func OIDCRoleUserNotIn ¶
func OIDCRoleUserNotIn(vs ...string) predicate.Authentication
OIDCRoleUserNotIn applies the NotIn predicate on the "OIDC_role_user" field.
func OIDCRoleUserNotNil ¶
func OIDCRoleUserNotNil() predicate.Authentication
OIDCRoleUserNotNil applies the NotNil predicate on the "OIDC_role_user" field.
func Or ¶
func Or(predicates ...predicate.Authentication) predicate.Authentication
Or groups predicates with the OR operator between them.
func UseCertificates ¶
func UseCertificates(v bool) predicate.Authentication
UseCertificates applies equality check predicate on the "use_certificates" field. It's identical to UseCertificatesEQ.
func UseCertificatesEQ ¶
func UseCertificatesEQ(v bool) predicate.Authentication
UseCertificatesEQ applies the EQ predicate on the "use_certificates" field.
func UseCertificatesIsNil ¶
func UseCertificatesIsNil() predicate.Authentication
UseCertificatesIsNil applies the IsNil predicate on the "use_certificates" field.
func UseCertificatesNEQ ¶
func UseCertificatesNEQ(v bool) predicate.Authentication
UseCertificatesNEQ applies the NEQ predicate on the "use_certificates" field.
func UseCertificatesNotNil ¶
func UseCertificatesNotNil() predicate.Authentication
UseCertificatesNotNil applies the NotNil predicate on the "use_certificates" field.
func UseOIDC ¶
func UseOIDC(v bool) predicate.Authentication
UseOIDC applies equality check predicate on the "use_OIDC" field. It's identical to UseOIDCEQ.
func UseOIDCEQ ¶
func UseOIDCEQ(v bool) predicate.Authentication
UseOIDCEQ applies the EQ predicate on the "use_OIDC" field.
func UseOIDCIsNil ¶
func UseOIDCIsNil() predicate.Authentication
UseOIDCIsNil applies the IsNil predicate on the "use_OIDC" field.
func UseOIDCNEQ ¶
func UseOIDCNEQ(v bool) predicate.Authentication
UseOIDCNEQ applies the NEQ predicate on the "use_OIDC" field.
func UseOIDCNotNil ¶
func UseOIDCNotNil() predicate.Authentication
UseOIDCNotNil applies the NotNil predicate on the "use_OIDC" field.
func UsePasswd ¶
func UsePasswd(v bool) predicate.Authentication
UsePasswd applies equality check predicate on the "use_passwd" field. It's identical to UsePasswdEQ.
func UsePasswdEQ ¶
func UsePasswdEQ(v bool) predicate.Authentication
UsePasswdEQ applies the EQ predicate on the "use_passwd" field.
func UsePasswdIsNil ¶
func UsePasswdIsNil() predicate.Authentication
UsePasswdIsNil applies the IsNil predicate on the "use_passwd" field.
func UsePasswdNEQ ¶
func UsePasswdNEQ(v bool) predicate.Authentication
UsePasswdNEQ applies the NEQ predicate on the "use_passwd" field.
func UsePasswdNotNil ¶
func UsePasswdNotNil() predicate.Authentication
UsePasswdNotNil applies the NotNil predicate on the "use_passwd" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Authentication queries.
func ByAllowRegister ¶
func ByAllowRegister(opts ...sql.OrderTermOption) OrderOption
ByAllowRegister orders the results by the allow_register field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByOIDCAutoApprove ¶
func ByOIDCAutoApprove(opts ...sql.OrderTermOption) OrderOption
ByOIDCAutoApprove orders the results by the OIDC_auto_approve field.
func ByOIDCAutoCreateAccount ¶
func ByOIDCAutoCreateAccount(opts ...sql.OrderTermOption) OrderOption
ByOIDCAutoCreateAccount orders the results by the OIDC_auto_create_account field.
func ByOIDCClientID ¶
func ByOIDCClientID(opts ...sql.OrderTermOption) OrderOption
ByOIDCClientID orders the results by the OIDC_client_id field.
func ByOIDCCookieEncriptionKey ¶
func ByOIDCCookieEncriptionKey(opts ...sql.OrderTermOption) OrderOption
ByOIDCCookieEncriptionKey orders the results by the OIDC_cookie_encription_key field.
func ByOIDCIssuerURL ¶
func ByOIDCIssuerURL(opts ...sql.OrderTermOption) OrderOption
ByOIDCIssuerURL orders the results by the OIDC_issuer_url field.
func ByOIDCKeycloakPublicKey ¶
func ByOIDCKeycloakPublicKey(opts ...sql.OrderTermOption) OrderOption
ByOIDCKeycloakPublicKey orders the results by the OIDC_keycloak_public_key field.
func ByOIDCProvider ¶
func ByOIDCProvider(opts ...sql.OrderTermOption) OrderOption
ByOIDCProvider orders the results by the OIDC_provider field.
func ByOIDCRoleAdmin ¶
func ByOIDCRoleAdmin(opts ...sql.OrderTermOption) OrderOption
ByOIDCRoleAdmin orders the results by the OIDC_role_admin field.
func ByOIDCRoleOperator ¶
func ByOIDCRoleOperator(opts ...sql.OrderTermOption) OrderOption
ByOIDCRoleOperator orders the results by the OIDC_role_operator field.
func ByOIDCRoleUser ¶
func ByOIDCRoleUser(opts ...sql.OrderTermOption) OrderOption
ByOIDCRoleUser orders the results by the OIDC_role_user field.
func ByUseCertificates ¶
func ByUseCertificates(opts ...sql.OrderTermOption) OrderOption
ByUseCertificates orders the results by the use_certificates field.
func ByUseOIDC ¶
func ByUseOIDC(opts ...sql.OrderTermOption) OrderOption
ByUseOIDC orders the results by the use_OIDC field.
func ByUsePasswd ¶
func ByUsePasswd(opts ...sql.OrderTermOption) OrderOption
ByUsePasswd orders the results by the use_passwd field.