branding

package
v0.0.0-...-d4cf3a4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the branding type in the database.
	Label = "branding"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldLogoLight holds the string denoting the logo_light field in the database.
	FieldLogoLight = "logo_light"
	// FieldLogoSmall holds the string denoting the logo_small field in the database.
	FieldLogoSmall = "logo_small"
	// FieldPrimaryColor holds the string denoting the primary_color field in the database.
	FieldPrimaryColor = "primary_color"
	// FieldProductName holds the string denoting the product_name field in the database.
	FieldProductName = "product_name"
	// FieldLoginBackgroundImage holds the string denoting the login_background_image field in the database.
	FieldLoginBackgroundImage = "login_background_image"
	// FieldLoginWelcomeText holds the string denoting the login_welcome_text field in the database.
	FieldLoginWelcomeText = "login_welcome_text"
	// FieldShowVersion holds the string denoting the show_version field in the database.
	FieldShowVersion = "show_version"
	// FieldBugReportLink holds the string denoting the bug_report_link field in the database.
	FieldBugReportLink = "bug_report_link"
	// FieldHelpLink holds the string denoting the help_link field in the database.
	FieldHelpLink = "help_link"
	// Table holds the table name of the branding in the database.
	Table = "brandings"
)

Variables

var (
	// DefaultPrimaryColor holds the default value on creation for the "primary_color" field.
	DefaultPrimaryColor string
	// DefaultProductName holds the default value on creation for the "product_name" field.
	DefaultProductName string
	// DefaultShowVersion holds the default value on creation for the "show_version" field.
	DefaultShowVersion bool
	// DefaultBugReportLink holds the default value on creation for the "bug_report_link" field.
	DefaultBugReportLink string
	// DefaultHelpLink holds the default value on creation for the "help_link" field.
	DefaultHelpLink string
)

Columns holds all SQL columns for branding fields.

Functions

func And

func And(predicates ...predicate.Branding) predicate.Branding

And groups predicates with the AND operator between them.

func BugReportLink(v string) predicate.Branding

BugReportLink applies equality check predicate on the "bug_report_link" field. It's identical to BugReportLinkEQ.

func BugReportLinkContains

func BugReportLinkContains(v string) predicate.Branding

BugReportLinkContains applies the Contains predicate on the "bug_report_link" field.

func BugReportLinkContainsFold

func BugReportLinkContainsFold(v string) predicate.Branding

BugReportLinkContainsFold applies the ContainsFold predicate on the "bug_report_link" field.

func BugReportLinkEQ

func BugReportLinkEQ(v string) predicate.Branding

BugReportLinkEQ applies the EQ predicate on the "bug_report_link" field.

func BugReportLinkEqualFold

func BugReportLinkEqualFold(v string) predicate.Branding

BugReportLinkEqualFold applies the EqualFold predicate on the "bug_report_link" field.

func BugReportLinkGT

func BugReportLinkGT(v string) predicate.Branding

BugReportLinkGT applies the GT predicate on the "bug_report_link" field.

func BugReportLinkGTE

func BugReportLinkGTE(v string) predicate.Branding

BugReportLinkGTE applies the GTE predicate on the "bug_report_link" field.

func BugReportLinkHasPrefix

func BugReportLinkHasPrefix(v string) predicate.Branding

BugReportLinkHasPrefix applies the HasPrefix predicate on the "bug_report_link" field.

func BugReportLinkHasSuffix

func BugReportLinkHasSuffix(v string) predicate.Branding

BugReportLinkHasSuffix applies the HasSuffix predicate on the "bug_report_link" field.

func BugReportLinkIn

func BugReportLinkIn(vs ...string) predicate.Branding

BugReportLinkIn applies the In predicate on the "bug_report_link" field.

func BugReportLinkIsNil

func BugReportLinkIsNil() predicate.Branding

BugReportLinkIsNil applies the IsNil predicate on the "bug_report_link" field.

func BugReportLinkLT

func BugReportLinkLT(v string) predicate.Branding

BugReportLinkLT applies the LT predicate on the "bug_report_link" field.

func BugReportLinkLTE

func BugReportLinkLTE(v string) predicate.Branding

BugReportLinkLTE applies the LTE predicate on the "bug_report_link" field.

func BugReportLinkNEQ

func BugReportLinkNEQ(v string) predicate.Branding

BugReportLinkNEQ applies the NEQ predicate on the "bug_report_link" field.

func BugReportLinkNotIn

func BugReportLinkNotIn(vs ...string) predicate.Branding

BugReportLinkNotIn applies the NotIn predicate on the "bug_report_link" field.

func BugReportLinkNotNil

func BugReportLinkNotNil() predicate.Branding

BugReportLinkNotNil applies the NotNil predicate on the "bug_report_link" field.

func HelpLink(v string) predicate.Branding

HelpLink applies equality check predicate on the "help_link" field. It's identical to HelpLinkEQ.

func HelpLinkContains

func HelpLinkContains(v string) predicate.Branding

HelpLinkContains applies the Contains predicate on the "help_link" field.

func HelpLinkContainsFold

func HelpLinkContainsFold(v string) predicate.Branding

HelpLinkContainsFold applies the ContainsFold predicate on the "help_link" field.

func HelpLinkEQ

func HelpLinkEQ(v string) predicate.Branding

HelpLinkEQ applies the EQ predicate on the "help_link" field.

func HelpLinkEqualFold

func HelpLinkEqualFold(v string) predicate.Branding

HelpLinkEqualFold applies the EqualFold predicate on the "help_link" field.

func HelpLinkGT

func HelpLinkGT(v string) predicate.Branding

HelpLinkGT applies the GT predicate on the "help_link" field.

func HelpLinkGTE

func HelpLinkGTE(v string) predicate.Branding

HelpLinkGTE applies the GTE predicate on the "help_link" field.

func HelpLinkHasPrefix

func HelpLinkHasPrefix(v string) predicate.Branding

HelpLinkHasPrefix applies the HasPrefix predicate on the "help_link" field.

func HelpLinkHasSuffix

func HelpLinkHasSuffix(v string) predicate.Branding

HelpLinkHasSuffix applies the HasSuffix predicate on the "help_link" field.

func HelpLinkIn

func HelpLinkIn(vs ...string) predicate.Branding

HelpLinkIn applies the In predicate on the "help_link" field.

func HelpLinkIsNil

func HelpLinkIsNil() predicate.Branding

HelpLinkIsNil applies the IsNil predicate on the "help_link" field.

func HelpLinkLT

func HelpLinkLT(v string) predicate.Branding

HelpLinkLT applies the LT predicate on the "help_link" field.

func HelpLinkLTE

func HelpLinkLTE(v string) predicate.Branding

HelpLinkLTE applies the LTE predicate on the "help_link" field.

func HelpLinkNEQ

func HelpLinkNEQ(v string) predicate.Branding

HelpLinkNEQ applies the NEQ predicate on the "help_link" field.

func HelpLinkNotIn

func HelpLinkNotIn(vs ...string) predicate.Branding

HelpLinkNotIn applies the NotIn predicate on the "help_link" field.

func HelpLinkNotNil

func HelpLinkNotNil() predicate.Branding

HelpLinkNotNil applies the NotNil predicate on the "help_link" field.

func ID

func ID(id int) predicate.Branding

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Branding

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Branding

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Branding

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Branding

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Branding

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Branding

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Branding

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Branding

IDNotIn applies the NotIn predicate on the ID field.

func LoginBackgroundImage

func LoginBackgroundImage(v string) predicate.Branding

LoginBackgroundImage applies equality check predicate on the "login_background_image" field. It's identical to LoginBackgroundImageEQ.

func LoginBackgroundImageContains

func LoginBackgroundImageContains(v string) predicate.Branding

LoginBackgroundImageContains applies the Contains predicate on the "login_background_image" field.

func LoginBackgroundImageContainsFold

func LoginBackgroundImageContainsFold(v string) predicate.Branding

LoginBackgroundImageContainsFold applies the ContainsFold predicate on the "login_background_image" field.

func LoginBackgroundImageEQ

func LoginBackgroundImageEQ(v string) predicate.Branding

LoginBackgroundImageEQ applies the EQ predicate on the "login_background_image" field.

func LoginBackgroundImageEqualFold

func LoginBackgroundImageEqualFold(v string) predicate.Branding

LoginBackgroundImageEqualFold applies the EqualFold predicate on the "login_background_image" field.

func LoginBackgroundImageGT

func LoginBackgroundImageGT(v string) predicate.Branding

LoginBackgroundImageGT applies the GT predicate on the "login_background_image" field.

func LoginBackgroundImageGTE

func LoginBackgroundImageGTE(v string) predicate.Branding

LoginBackgroundImageGTE applies the GTE predicate on the "login_background_image" field.

func LoginBackgroundImageHasPrefix

func LoginBackgroundImageHasPrefix(v string) predicate.Branding

LoginBackgroundImageHasPrefix applies the HasPrefix predicate on the "login_background_image" field.

func LoginBackgroundImageHasSuffix

func LoginBackgroundImageHasSuffix(v string) predicate.Branding

LoginBackgroundImageHasSuffix applies the HasSuffix predicate on the "login_background_image" field.

func LoginBackgroundImageIn

func LoginBackgroundImageIn(vs ...string) predicate.Branding

LoginBackgroundImageIn applies the In predicate on the "login_background_image" field.

func LoginBackgroundImageIsNil

func LoginBackgroundImageIsNil() predicate.Branding

LoginBackgroundImageIsNil applies the IsNil predicate on the "login_background_image" field.

func LoginBackgroundImageLT

func LoginBackgroundImageLT(v string) predicate.Branding

LoginBackgroundImageLT applies the LT predicate on the "login_background_image" field.

func LoginBackgroundImageLTE

func LoginBackgroundImageLTE(v string) predicate.Branding

LoginBackgroundImageLTE applies the LTE predicate on the "login_background_image" field.

func LoginBackgroundImageNEQ

func LoginBackgroundImageNEQ(v string) predicate.Branding

LoginBackgroundImageNEQ applies the NEQ predicate on the "login_background_image" field.

func LoginBackgroundImageNotIn

func LoginBackgroundImageNotIn(vs ...string) predicate.Branding

LoginBackgroundImageNotIn applies the NotIn predicate on the "login_background_image" field.

func LoginBackgroundImageNotNil

func LoginBackgroundImageNotNil() predicate.Branding

LoginBackgroundImageNotNil applies the NotNil predicate on the "login_background_image" field.

func LoginWelcomeText

func LoginWelcomeText(v string) predicate.Branding

LoginWelcomeText applies equality check predicate on the "login_welcome_text" field. It's identical to LoginWelcomeTextEQ.

func LoginWelcomeTextContains

func LoginWelcomeTextContains(v string) predicate.Branding

LoginWelcomeTextContains applies the Contains predicate on the "login_welcome_text" field.

func LoginWelcomeTextContainsFold

func LoginWelcomeTextContainsFold(v string) predicate.Branding

LoginWelcomeTextContainsFold applies the ContainsFold predicate on the "login_welcome_text" field.

func LoginWelcomeTextEQ

func LoginWelcomeTextEQ(v string) predicate.Branding

LoginWelcomeTextEQ applies the EQ predicate on the "login_welcome_text" field.

func LoginWelcomeTextEqualFold

func LoginWelcomeTextEqualFold(v string) predicate.Branding

LoginWelcomeTextEqualFold applies the EqualFold predicate on the "login_welcome_text" field.

func LoginWelcomeTextGT

func LoginWelcomeTextGT(v string) predicate.Branding

LoginWelcomeTextGT applies the GT predicate on the "login_welcome_text" field.

func LoginWelcomeTextGTE

func LoginWelcomeTextGTE(v string) predicate.Branding

LoginWelcomeTextGTE applies the GTE predicate on the "login_welcome_text" field.

func LoginWelcomeTextHasPrefix

func LoginWelcomeTextHasPrefix(v string) predicate.Branding

LoginWelcomeTextHasPrefix applies the HasPrefix predicate on the "login_welcome_text" field.

func LoginWelcomeTextHasSuffix

func LoginWelcomeTextHasSuffix(v string) predicate.Branding

LoginWelcomeTextHasSuffix applies the HasSuffix predicate on the "login_welcome_text" field.

func LoginWelcomeTextIn

func LoginWelcomeTextIn(vs ...string) predicate.Branding

LoginWelcomeTextIn applies the In predicate on the "login_welcome_text" field.

func LoginWelcomeTextIsNil

func LoginWelcomeTextIsNil() predicate.Branding

LoginWelcomeTextIsNil applies the IsNil predicate on the "login_welcome_text" field.

func LoginWelcomeTextLT

func LoginWelcomeTextLT(v string) predicate.Branding

LoginWelcomeTextLT applies the LT predicate on the "login_welcome_text" field.

func LoginWelcomeTextLTE

func LoginWelcomeTextLTE(v string) predicate.Branding

LoginWelcomeTextLTE applies the LTE predicate on the "login_welcome_text" field.

func LoginWelcomeTextNEQ

func LoginWelcomeTextNEQ(v string) predicate.Branding

LoginWelcomeTextNEQ applies the NEQ predicate on the "login_welcome_text" field.

func LoginWelcomeTextNotIn

func LoginWelcomeTextNotIn(vs ...string) predicate.Branding

LoginWelcomeTextNotIn applies the NotIn predicate on the "login_welcome_text" field.

func LoginWelcomeTextNotNil

func LoginWelcomeTextNotNil() predicate.Branding

LoginWelcomeTextNotNil applies the NotNil predicate on the "login_welcome_text" field.

func LogoLight

func LogoLight(v string) predicate.Branding

LogoLight applies equality check predicate on the "logo_light" field. It's identical to LogoLightEQ.

func LogoLightContains

func LogoLightContains(v string) predicate.Branding

LogoLightContains applies the Contains predicate on the "logo_light" field.

func LogoLightContainsFold

func LogoLightContainsFold(v string) predicate.Branding

LogoLightContainsFold applies the ContainsFold predicate on the "logo_light" field.

func LogoLightEQ

func LogoLightEQ(v string) predicate.Branding

LogoLightEQ applies the EQ predicate on the "logo_light" field.

func LogoLightEqualFold

func LogoLightEqualFold(v string) predicate.Branding

LogoLightEqualFold applies the EqualFold predicate on the "logo_light" field.

func LogoLightGT

func LogoLightGT(v string) predicate.Branding

LogoLightGT applies the GT predicate on the "logo_light" field.

func LogoLightGTE

func LogoLightGTE(v string) predicate.Branding

LogoLightGTE applies the GTE predicate on the "logo_light" field.

func LogoLightHasPrefix

func LogoLightHasPrefix(v string) predicate.Branding

LogoLightHasPrefix applies the HasPrefix predicate on the "logo_light" field.

func LogoLightHasSuffix

func LogoLightHasSuffix(v string) predicate.Branding

LogoLightHasSuffix applies the HasSuffix predicate on the "logo_light" field.

func LogoLightIn

func LogoLightIn(vs ...string) predicate.Branding

LogoLightIn applies the In predicate on the "logo_light" field.

func LogoLightIsNil

func LogoLightIsNil() predicate.Branding

LogoLightIsNil applies the IsNil predicate on the "logo_light" field.

func LogoLightLT

func LogoLightLT(v string) predicate.Branding

LogoLightLT applies the LT predicate on the "logo_light" field.

func LogoLightLTE

func LogoLightLTE(v string) predicate.Branding

LogoLightLTE applies the LTE predicate on the "logo_light" field.

func LogoLightNEQ

func LogoLightNEQ(v string) predicate.Branding

LogoLightNEQ applies the NEQ predicate on the "logo_light" field.

func LogoLightNotIn

func LogoLightNotIn(vs ...string) predicate.Branding

LogoLightNotIn applies the NotIn predicate on the "logo_light" field.

func LogoLightNotNil

func LogoLightNotNil() predicate.Branding

LogoLightNotNil applies the NotNil predicate on the "logo_light" field.

func LogoSmall

func LogoSmall(v string) predicate.Branding

LogoSmall applies equality check predicate on the "logo_small" field. It's identical to LogoSmallEQ.

func LogoSmallContains

func LogoSmallContains(v string) predicate.Branding

LogoSmallContains applies the Contains predicate on the "logo_small" field.

func LogoSmallContainsFold

func LogoSmallContainsFold(v string) predicate.Branding

LogoSmallContainsFold applies the ContainsFold predicate on the "logo_small" field.

func LogoSmallEQ

func LogoSmallEQ(v string) predicate.Branding

LogoSmallEQ applies the EQ predicate on the "logo_small" field.

func LogoSmallEqualFold

func LogoSmallEqualFold(v string) predicate.Branding

LogoSmallEqualFold applies the EqualFold predicate on the "logo_small" field.

func LogoSmallGT

func LogoSmallGT(v string) predicate.Branding

LogoSmallGT applies the GT predicate on the "logo_small" field.

func LogoSmallGTE

func LogoSmallGTE(v string) predicate.Branding

LogoSmallGTE applies the GTE predicate on the "logo_small" field.

func LogoSmallHasPrefix

func LogoSmallHasPrefix(v string) predicate.Branding

LogoSmallHasPrefix applies the HasPrefix predicate on the "logo_small" field.

func LogoSmallHasSuffix

func LogoSmallHasSuffix(v string) predicate.Branding

LogoSmallHasSuffix applies the HasSuffix predicate on the "logo_small" field.

func LogoSmallIn

func LogoSmallIn(vs ...string) predicate.Branding

LogoSmallIn applies the In predicate on the "logo_small" field.

func LogoSmallIsNil

func LogoSmallIsNil() predicate.Branding

LogoSmallIsNil applies the IsNil predicate on the "logo_small" field.

func LogoSmallLT

func LogoSmallLT(v string) predicate.Branding

LogoSmallLT applies the LT predicate on the "logo_small" field.

func LogoSmallLTE

func LogoSmallLTE(v string) predicate.Branding

LogoSmallLTE applies the LTE predicate on the "logo_small" field.

func LogoSmallNEQ

func LogoSmallNEQ(v string) predicate.Branding

LogoSmallNEQ applies the NEQ predicate on the "logo_small" field.

func LogoSmallNotIn

func LogoSmallNotIn(vs ...string) predicate.Branding

LogoSmallNotIn applies the NotIn predicate on the "logo_small" field.

func LogoSmallNotNil

func LogoSmallNotNil() predicate.Branding

LogoSmallNotNil applies the NotNil predicate on the "logo_small" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Branding) predicate.Branding

Or groups predicates with the OR operator between them.

func PrimaryColor

func PrimaryColor(v string) predicate.Branding

PrimaryColor applies equality check predicate on the "primary_color" field. It's identical to PrimaryColorEQ.

func PrimaryColorContains

func PrimaryColorContains(v string) predicate.Branding

PrimaryColorContains applies the Contains predicate on the "primary_color" field.

func PrimaryColorContainsFold

func PrimaryColorContainsFold(v string) predicate.Branding

PrimaryColorContainsFold applies the ContainsFold predicate on the "primary_color" field.

func PrimaryColorEQ

func PrimaryColorEQ(v string) predicate.Branding

PrimaryColorEQ applies the EQ predicate on the "primary_color" field.

func PrimaryColorEqualFold

func PrimaryColorEqualFold(v string) predicate.Branding

PrimaryColorEqualFold applies the EqualFold predicate on the "primary_color" field.

func PrimaryColorGT

func PrimaryColorGT(v string) predicate.Branding

PrimaryColorGT applies the GT predicate on the "primary_color" field.

func PrimaryColorGTE

func PrimaryColorGTE(v string) predicate.Branding

PrimaryColorGTE applies the GTE predicate on the "primary_color" field.

func PrimaryColorHasPrefix

func PrimaryColorHasPrefix(v string) predicate.Branding

PrimaryColorHasPrefix applies the HasPrefix predicate on the "primary_color" field.

func PrimaryColorHasSuffix

func PrimaryColorHasSuffix(v string) predicate.Branding

PrimaryColorHasSuffix applies the HasSuffix predicate on the "primary_color" field.

func PrimaryColorIn

func PrimaryColorIn(vs ...string) predicate.Branding

PrimaryColorIn applies the In predicate on the "primary_color" field.

func PrimaryColorIsNil

func PrimaryColorIsNil() predicate.Branding

PrimaryColorIsNil applies the IsNil predicate on the "primary_color" field.

func PrimaryColorLT

func PrimaryColorLT(v string) predicate.Branding

PrimaryColorLT applies the LT predicate on the "primary_color" field.

func PrimaryColorLTE

func PrimaryColorLTE(v string) predicate.Branding

PrimaryColorLTE applies the LTE predicate on the "primary_color" field.

func PrimaryColorNEQ

func PrimaryColorNEQ(v string) predicate.Branding

PrimaryColorNEQ applies the NEQ predicate on the "primary_color" field.

func PrimaryColorNotIn

func PrimaryColorNotIn(vs ...string) predicate.Branding

PrimaryColorNotIn applies the NotIn predicate on the "primary_color" field.

func PrimaryColorNotNil

func PrimaryColorNotNil() predicate.Branding

PrimaryColorNotNil applies the NotNil predicate on the "primary_color" field.

func ProductName

func ProductName(v string) predicate.Branding

ProductName applies equality check predicate on the "product_name" field. It's identical to ProductNameEQ.

func ProductNameContains

func ProductNameContains(v string) predicate.Branding

ProductNameContains applies the Contains predicate on the "product_name" field.

func ProductNameContainsFold

func ProductNameContainsFold(v string) predicate.Branding

ProductNameContainsFold applies the ContainsFold predicate on the "product_name" field.

func ProductNameEQ

func ProductNameEQ(v string) predicate.Branding

ProductNameEQ applies the EQ predicate on the "product_name" field.

func ProductNameEqualFold

func ProductNameEqualFold(v string) predicate.Branding

ProductNameEqualFold applies the EqualFold predicate on the "product_name" field.

func ProductNameGT

func ProductNameGT(v string) predicate.Branding

ProductNameGT applies the GT predicate on the "product_name" field.

func ProductNameGTE

func ProductNameGTE(v string) predicate.Branding

ProductNameGTE applies the GTE predicate on the "product_name" field.

func ProductNameHasPrefix

func ProductNameHasPrefix(v string) predicate.Branding

ProductNameHasPrefix applies the HasPrefix predicate on the "product_name" field.

func ProductNameHasSuffix

func ProductNameHasSuffix(v string) predicate.Branding

ProductNameHasSuffix applies the HasSuffix predicate on the "product_name" field.

func ProductNameIn

func ProductNameIn(vs ...string) predicate.Branding

ProductNameIn applies the In predicate on the "product_name" field.

func ProductNameIsNil

func ProductNameIsNil() predicate.Branding

ProductNameIsNil applies the IsNil predicate on the "product_name" field.

func ProductNameLT

func ProductNameLT(v string) predicate.Branding

ProductNameLT applies the LT predicate on the "product_name" field.

func ProductNameLTE

func ProductNameLTE(v string) predicate.Branding

ProductNameLTE applies the LTE predicate on the "product_name" field.

func ProductNameNEQ

func ProductNameNEQ(v string) predicate.Branding

ProductNameNEQ applies the NEQ predicate on the "product_name" field.

func ProductNameNotIn

func ProductNameNotIn(vs ...string) predicate.Branding

ProductNameNotIn applies the NotIn predicate on the "product_name" field.

func ProductNameNotNil

func ProductNameNotNil() predicate.Branding

ProductNameNotNil applies the NotNil predicate on the "product_name" field.

func ShowVersion

func ShowVersion(v bool) predicate.Branding

ShowVersion applies equality check predicate on the "show_version" field. It's identical to ShowVersionEQ.

func ShowVersionEQ

func ShowVersionEQ(v bool) predicate.Branding

ShowVersionEQ applies the EQ predicate on the "show_version" field.

func ShowVersionIsNil

func ShowVersionIsNil() predicate.Branding

ShowVersionIsNil applies the IsNil predicate on the "show_version" field.

func ShowVersionNEQ

func ShowVersionNEQ(v bool) predicate.Branding

ShowVersionNEQ applies the NEQ predicate on the "show_version" field.

func ShowVersionNotNil

func ShowVersionNotNil() predicate.Branding

ShowVersionNotNil applies the NotNil predicate on the "show_version" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Branding queries.

func ByBugReportLink(opts ...sql.OrderTermOption) OrderOption

ByBugReportLink orders the results by the bug_report_link field.

func ByHelpLink(opts ...sql.OrderTermOption) OrderOption

ByHelpLink orders the results by the help_link field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLoginBackgroundImage

func ByLoginBackgroundImage(opts ...sql.OrderTermOption) OrderOption

ByLoginBackgroundImage orders the results by the login_background_image field.

func ByLoginWelcomeText

func ByLoginWelcomeText(opts ...sql.OrderTermOption) OrderOption

ByLoginWelcomeText orders the results by the login_welcome_text field.

func ByLogoLight

func ByLogoLight(opts ...sql.OrderTermOption) OrderOption

ByLogoLight orders the results by the logo_light field.

func ByLogoSmall

func ByLogoSmall(opts ...sql.OrderTermOption) OrderOption

ByLogoSmall orders the results by the logo_small field.

func ByPrimaryColor

func ByPrimaryColor(opts ...sql.OrderTermOption) OrderOption

ByPrimaryColor orders the results by the primary_color field.

func ByProductName

func ByProductName(opts ...sql.OrderTermOption) OrderOption

ByProductName orders the results by the product_name field.

func ByShowVersion

func ByShowVersion(opts ...sql.OrderTermOption) OrderOption

ByShowVersion orders the results by the show_version field.

Jump to