schema

package
v0.0.0-...-d4cf3a4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Agent

type Agent struct {
	ent.Schema
}

Agent holds the schema definition for the Agent entity.

func (Agent) Edges

func (Agent) Edges() []ent.Edge

Edges of the Agent.

func (Agent) Fields

func (Agent) Fields() []ent.Field

Fields of the Agent.

func (Agent) Indexes

func (Agent) Indexes() []ent.Index

Indexes of the Agent.

type Antivirus

type Antivirus struct {
	ent.Schema
}

Antivirus holds the schema definition for the Antivirus entity.

func (Antivirus) Edges

func (Antivirus) Edges() []ent.Edge

Edges of the Antivirus.

func (Antivirus) Fields

func (Antivirus) Fields() []ent.Field

Fields of the Antivirus.

type App

type App struct {
	ent.Schema
}

App holds the schema definition for the App entity.

func (App) Edges

func (App) Edges() []ent.Edge

Edges of the App.

func (App) Fields

func (App) Fields() []ent.Field

Fields of the App.

type Authentication

type Authentication struct {
	ent.Schema
}

Authentication holds the schema definition for the Authentication entity.

func (Authentication) Fields

func (Authentication) Fields() []ent.Field

Fields of the Authentication.

type Branding

type Branding struct {
	ent.Schema
}

Branding holds the schema definition for the Branding entity. This stores global provider branding settings that apply across all tenants.

func (Branding) Edges

func (Branding) Edges() []ent.Edge

Edges of the Branding.

func (Branding) Fields

func (Branding) Fields() []ent.Field

Fields of the Branding.

type Certificate

type Certificate struct {
	ent.Schema
}

Certificate holds the schema definition for the Certificate entity.

func (Certificate) Edges

func (Certificate) Edges() []ent.Edge

Edges of the Certificate.

func (Certificate) Fields

func (Certificate) Fields() []ent.Field

Fields of the Certificate.

type Computer

type Computer struct {
	ent.Schema
}

Computer holds the schema definition for the Computer entity.

func (Computer) Edges

func (Computer) Edges() []ent.Edge

Edges of the Computer.

func (Computer) Fields

func (Computer) Fields() []ent.Field

Fields of the Computer.

type Deployment

type Deployment struct {
	ent.Schema
}

Deployment holds the schema definition for the Deployment entity.

func (Deployment) Edges

func (Deployment) Edges() []ent.Edge

Edges of the Deployment.

func (Deployment) Fields

func (Deployment) Fields() []ent.Field

Fields of the Deployment.

type EnrollmentToken

type EnrollmentToken struct {
	ent.Schema
}

EnrollmentToken holds the schema definition for the EnrollmentToken entity. Enrollment tokens allow tenant admins to securely register agents to their tenant.

func (EnrollmentToken) Edges

func (EnrollmentToken) Edges() []ent.Edge

Edges of the EnrollmentToken.

func (EnrollmentToken) Fields

func (EnrollmentToken) Fields() []ent.Field

Fields of the EnrollmentToken.

type LogicalDisk

type LogicalDisk struct {
	ent.Schema
}

Logical Disk holds the schema definition for the Logical Disk entity.

func (LogicalDisk) Edges

func (LogicalDisk) Edges() []ent.Edge

Edges of the Logical Disk.

func (LogicalDisk) Fields

func (LogicalDisk) Fields() []ent.Field

Fields of the Logical Disk.

type ManagedPackage

type ManagedPackage struct {
	ent.Schema
}

ManagedPackage holds the schema definition for the ManagedPackage entity.

func (ManagedPackage) Edges

func (ManagedPackage) Edges() []ent.Edge

Edges of the ManagedPackage.

func (ManagedPackage) Fields

func (ManagedPackage) Fields() []ent.Field

Fields of the ManagedPackage.

func (ManagedPackage) Indexes

func (ManagedPackage) Indexes() []ent.Index

Indexes of the ManagedPackage.

type MemorySlot

type MemorySlot struct {
	ent.Schema
}

MemorySlot holds the schema definition for the MemorySlot entity.

func (MemorySlot) Edges

func (MemorySlot) Edges() []ent.Edge

Edges of the MemorySlot.

func (MemorySlot) Fields

func (MemorySlot) Fields() []ent.Field

Fields of the MemorySlot.

type Metadata

type Metadata struct {
	ent.Schema
}

Metadata holds the schema definition for the Metadata entity.

func (Metadata) Edges

func (Metadata) Edges() []ent.Edge

Edges of the Metadata.

func (Metadata) Fields

func (Metadata) Fields() []ent.Field

Fields of the Metadata.

func (Metadata) Indexes

func (Metadata) Indexes() []ent.Index

Indexes of the Metadata.

type Monitor

type Monitor struct {
	ent.Schema
}

Monitor holds the schema definition for the Monitor entity.

func (Monitor) Edges

func (Monitor) Edges() []ent.Edge

Edges of the Monitor.

func (Monitor) Fields

func (Monitor) Fields() []ent.Field

Fields of the Monitor.

type Netbird

type Netbird struct {
	ent.Schema
}

Netbird holds the schema definition for the Netbird entity.

func (Netbird) Edges

func (Netbird) Edges() []ent.Edge

Edges of the Netbird.

func (Netbird) Fields

func (Netbird) Fields() []ent.Field

Fields of the Netbird.

type NetbirdSettings

type NetbirdSettings struct {
	ent.Schema
}

NetbirdSettings holds the schema definition for the NetbirdSettings entity.

func (NetbirdSettings) Edges

func (NetbirdSettings) Edges() []ent.Edge

Edges of the NetbirdSettings.

func (NetbirdSettings) Fields

func (NetbirdSettings) Fields() []ent.Field

Fields of the NetbirdSettings.

type NetworkAdapter

type NetworkAdapter struct {
	ent.Schema
}

NetworkAdapter holds the schema definition for the NetworkAdapter entity.

func (NetworkAdapter) Edges

func (NetworkAdapter) Edges() []ent.Edge

Edges of the NetworkAdapter.

func (NetworkAdapter) Fields

func (NetworkAdapter) Fields() []ent.Field

Fields of the NetworkAdapter.

type OperatingSystem

type OperatingSystem struct {
	ent.Schema
}

OperatingSystem holds the schema definition for the OperatingSystem entity.

func (OperatingSystem) Edges

func (OperatingSystem) Edges() []ent.Edge

Edges of the OperatingSystem.

func (OperatingSystem) Fields

func (OperatingSystem) Fields() []ent.Field

Fields of the OperatingSystem.

type OrgMetadata

type OrgMetadata struct {
	ent.Schema
}

OrgMetadata holds the schema definition for the OrgMetadata entity.

func (OrgMetadata) Edges

func (OrgMetadata) Edges() []ent.Edge

Edges of the OrgMetadata.

func (OrgMetadata) Fields

func (OrgMetadata) Fields() []ent.Field

Fields of the OrgMetadata.

type PhysicalDisk

type PhysicalDisk struct {
	ent.Schema
}

Physical Disk holds the schema definition for the Physical Disk entity.

func (PhysicalDisk) Edges

func (PhysicalDisk) Edges() []ent.Edge

Edges of the Physical Disk.

func (PhysicalDisk) Fields

func (PhysicalDisk) Fields() []ent.Field

Fields of the Physical Disk.

type Printer

type Printer struct {
	ent.Schema
}

Printer holds the schema definition for the Printer entity.

func (Printer) Edges

func (Printer) Edges() []ent.Edge

Edges of the Printer.

func (Printer) Fields

func (Printer) Fields() []ent.Field

Fields of the Printer.

type Profile

type Profile struct {
	ent.Schema
}

Profile holds the schema definition for the Profile entity.

func (Profile) Edges

func (Profile) Edges() []ent.Edge

Edges of the Profile.

func (Profile) Fields

func (Profile) Fields() []ent.Field

Fields of the Profile.

type ProfileIssue

type ProfileIssue struct {
	ent.Schema
}

ProfileIssue holds the schema definition for the ProfileIssue entity.

func (ProfileIssue) Edges

func (ProfileIssue) Edges() []ent.Edge

Edges of the ProfileIssue.

func (ProfileIssue) Fields

func (ProfileIssue) Fields() []ent.Field

Fields of the ProfileIssue.

type RecoveryCode

type RecoveryCode struct {
	ent.Schema
}

RecoveryCode holds the schema definition for the RecoveryCode entity.

func (RecoveryCode) Edges

func (RecoveryCode) Edges() []ent.Edge

func (RecoveryCode) Fields

func (RecoveryCode) Fields() []ent.Field

Fields of the RecoveryCode.

type Release

type Release struct {
	ent.Schema
}

Release holds the schema definition for the Release entity.

func (Release) Edges

func (Release) Edges() []ent.Edge

Edges of the Release.

func (Release) Fields

func (Release) Fields() []ent.Field

func (Release) Indexes

func (Release) Indexes() []ent.Index

Indexes of the Release.

type Revocation

type Revocation struct {
	ent.Schema
}

Revocation holds the schema definition for the Revocation entity.

func (Revocation) Fields

func (Revocation) Fields() []ent.Field

Fields of the Revocation.

type Rustdesk

type Rustdesk struct {
	ent.Schema
}

Rustdesk holds the schema definition for the Rustdesk entity.

func (Rustdesk) Edges

func (Rustdesk) Edges() []ent.Edge

Edges of the Rustdesk.

func (Rustdesk) Fields

func (Rustdesk) Fields() []ent.Field

Fields of the Rustdesk.

type Server

type Server struct {
	ent.Schema
}

Server holds the schema definition for the Server entity.

func (Server) Fields

func (Server) Fields() []ent.Field

Fields of the Server.

func (Server) Indexes

func (Server) Indexes() []ent.Index

Indexes of the Server.

type Sessions

type Sessions struct {
	ent.Schema
}

Sessions holds the schema definition for the Sessions entity.

func (Sessions) Edges

func (Sessions) Edges() []ent.Edge

func (Sessions) Fields

func (Sessions) Fields() []ent.Field

Fields of the Sessions.

func (Sessions) Indexes

func (Sessions) Indexes() []ent.Index

type Settings

type Settings struct {
	ent.Schema
}

Settings holds the schema definition for the Settings entity.

func (Settings) Edges

func (Settings) Edges() []ent.Edge

Edges of the Settings.

func (Settings) Fields

func (Settings) Fields() []ent.Field

Fields of the Settings.

type Share

type Share struct {
	ent.Schema
}

Share holds the schema definition for the Share entity.

func (Share) Edges

func (Share) Edges() []ent.Edge

Edges of the Share.

func (Share) Fields

func (Share) Fields() []ent.Field

Fields of the Share.

type Site

type Site struct {
	ent.Schema
}

Site holds the schema definition for the Site entity.

func (Site) Edges

func (Site) Edges() []ent.Edge

Edges of the Site.

func (Site) Fields

func (Site) Fields() []ent.Field

Fields of the Site.

type SoftwareAssignment

type SoftwareAssignment struct {
	ent.Schema
}

SoftwareAssignment holds the schema definition for the SoftwareAssignment entity.

func (SoftwareAssignment) Edges

func (SoftwareAssignment) Edges() []ent.Edge

Edges of the SoftwareAssignment.

func (SoftwareAssignment) Fields

func (SoftwareAssignment) Fields() []ent.Field

Fields of the SoftwareAssignment.

func (SoftwareAssignment) Indexes

func (SoftwareAssignment) Indexes() []ent.Index

Indexes of the SoftwareAssignment.

type SoftwareCatalog

type SoftwareCatalog struct {
	ent.Schema
}

SoftwareCatalog holds the schema definition for the SoftwareCatalog entity.

func (SoftwareCatalog) Edges

func (SoftwareCatalog) Edges() []ent.Edge

Edges of the SoftwareCatalog.

func (SoftwareCatalog) Fields

func (SoftwareCatalog) Fields() []ent.Field

Fields of the SoftwareCatalog.

func (SoftwareCatalog) Indexes

func (SoftwareCatalog) Indexes() []ent.Index

Indexes of the SoftwareCatalog.

type SoftwareInstallLog

type SoftwareInstallLog struct {
	ent.Schema
}

SoftwareInstallLog holds the schema definition for the SoftwareInstallLog entity.

func (SoftwareInstallLog) Edges

func (SoftwareInstallLog) Edges() []ent.Edge

Edges of the SoftwareInstallLog.

func (SoftwareInstallLog) Fields

func (SoftwareInstallLog) Fields() []ent.Field

Fields of the SoftwareInstallLog.

func (SoftwareInstallLog) Indexes

func (SoftwareInstallLog) Indexes() []ent.Index

Indexes of the SoftwareInstallLog.

type SoftwarePackage

type SoftwarePackage struct {
	ent.Schema
}

SoftwarePackage holds the schema definition for the SoftwarePackage entity.

func (SoftwarePackage) Fields

func (SoftwarePackage) Fields() []ent.Field

Fields of the SoftwarePackage.

type SoftwareRepo

type SoftwareRepo struct {
	ent.Schema
}

SoftwareRepo holds the schema definition for the SoftwareRepo entity.

func (SoftwareRepo) Edges

func (SoftwareRepo) Edges() []ent.Edge

Edges of the SoftwareRepo.

func (SoftwareRepo) Fields

func (SoftwareRepo) Fields() []ent.Field

Fields of the SoftwareRepo.

func (SoftwareRepo) Indexes

func (SoftwareRepo) Indexes() []ent.Index

Indexes of the SoftwareRepo.

type SystemUpdate

type SystemUpdate struct {
	ent.Schema
}

SystemUpdate holds the schema definition for the SystemUpdate entity.

func (SystemUpdate) Edges

func (SystemUpdate) Edges() []ent.Edge

Edges of the SystemUpdate.

func (SystemUpdate) Fields

func (SystemUpdate) Fields() []ent.Field

Fields of the SystemUpdate.

type Tag

type Tag struct {
	ent.Schema
}

Tag holds the schema definition for the Tag entity.

func (Tag) Edges

func (Tag) Edges() []ent.Edge

Edges of the Tag.

func (Tag) Fields

func (Tag) Fields() []ent.Field

Fields of the Tag.

type Task

type Task struct {
	ent.Schema
}

Task holds the schema definition for the Task entity.

func (Task) Edges

func (Task) Edges() []ent.Edge

Edges of the Task.

func (Task) Fields

func (Task) Fields() []ent.Field

Fields of the Task.

type TaskReport

type TaskReport struct {
	ent.Schema
}

TaskReport holds the schema definition for the Task entity.

func (TaskReport) Edges

func (TaskReport) Edges() []ent.Edge

Edges of the TaskReport.

func (TaskReport) Fields

func (TaskReport) Fields() []ent.Field

Fields of the Task.

type Tenant

type Tenant struct {
	ent.Schema
}

Tenant holds the schema definition for the Tenant entity.

func (Tenant) Edges

func (Tenant) Edges() []ent.Edge

Edges of the Tenant.

func (Tenant) Fields

func (Tenant) Fields() []ent.Field

Fields of the Tenant.

type Update

type Update struct {
	ent.Schema
}

Update holds the schema definition for the Update entity.

func (Update) Edges

func (Update) Edges() []ent.Edge

Edges of the Update.

func (Update) Fields

func (Update) Fields() []ent.Field

Fields of the Update.

type User

type User struct {
	ent.Schema
}

User holds the schema definition for the User entity.

func (User) Edges

func (User) Edges() []ent.Edge

func (User) Fields

func (User) Fields() []ent.Field

Fields of the User.

func (User) Indexes

func (User) Indexes() []ent.Index

type UserTenant

type UserTenant struct {
	ent.Schema
}

UserTenant holds the schema definition for the User-Tenant relationship. This is the junction table that connects users to tenants with their role.

func (UserTenant) Edges

func (UserTenant) Edges() []ent.Edge

Edges of the UserTenant.

func (UserTenant) Fields

func (UserTenant) Fields() []ent.Field

Fields of the UserTenant.

func (UserTenant) Indexes

func (UserTenant) Indexes() []ent.Index

Indexes of the UserTenant.

type WingetConfigExclusion

type WingetConfigExclusion struct {
	ent.Schema
}

holds the schema definition for the WingetConfigExclusion entity.

func (WingetConfigExclusion) Edges

func (WingetConfigExclusion) Edges() []ent.Edge

Edges of the WingetConfigExclusion.

func (WingetConfigExclusion) Fields

func (WingetConfigExclusion) Fields() []ent.Field

Fields of the WingetConfigExclusion.

Jump to