wingetconfigexclusion

package
v0.0.0-...-d4cf3a4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the wingetconfigexclusion type in the database.
	Label = "winget_config_exclusion"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldPackageID holds the string denoting the package_id field in the database.
	FieldPackageID = "package_id"
	// FieldWhen holds the string denoting the when field in the database.
	FieldWhen = "when"
	// EdgeOwner holds the string denoting the owner edge name in mutations.
	EdgeOwner = "owner"
	// AgentFieldID holds the string denoting the ID field of the Agent.
	AgentFieldID = "oid"
	// Table holds the table name of the wingetconfigexclusion in the database.
	Table = "winget_config_exclusions"
	// OwnerTable is the table that holds the owner relation/edge.
	OwnerTable = "winget_config_exclusions"
	// OwnerInverseTable is the table name for the Agent entity.
	// It exists in this package in order to avoid circular dependency with the "agent" package.
	OwnerInverseTable = "agents"
	// OwnerColumn is the table column denoting the owner relation/edge.
	OwnerColumn = "agent_wingetcfgexclusions"
)

Variables

Columns holds all SQL columns for wingetconfigexclusion fields.

var (
	// DefaultWhen holds the default value on creation for the "when" field.
	DefaultWhen func() time.Time
)
var ForeignKeys = []string{
	"agent_wingetcfgexclusions",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "winget_config_exclusions" table and are not defined as standalone fields in the schema.

Functions

func And

And groups predicates with the AND operator between them.

func HasOwner

HasOwner applies the HasEdge predicate on the "owner" edge.

func HasOwnerWith

func HasOwnerWith(preds ...predicate.Agent) predicate.WingetConfigExclusion

HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.WingetConfigExclusion

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.WingetConfigExclusion

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func PackageID

PackageID applies equality check predicate on the "package_id" field. It's identical to PackageIDEQ.

func PackageIDContains

func PackageIDContains(v string) predicate.WingetConfigExclusion

PackageIDContains applies the Contains predicate on the "package_id" field.

func PackageIDContainsFold

func PackageIDContainsFold(v string) predicate.WingetConfigExclusion

PackageIDContainsFold applies the ContainsFold predicate on the "package_id" field.

func PackageIDEQ

func PackageIDEQ(v string) predicate.WingetConfigExclusion

PackageIDEQ applies the EQ predicate on the "package_id" field.

func PackageIDEqualFold

func PackageIDEqualFold(v string) predicate.WingetConfigExclusion

PackageIDEqualFold applies the EqualFold predicate on the "package_id" field.

func PackageIDGT

func PackageIDGT(v string) predicate.WingetConfigExclusion

PackageIDGT applies the GT predicate on the "package_id" field.

func PackageIDGTE

func PackageIDGTE(v string) predicate.WingetConfigExclusion

PackageIDGTE applies the GTE predicate on the "package_id" field.

func PackageIDHasPrefix

func PackageIDHasPrefix(v string) predicate.WingetConfigExclusion

PackageIDHasPrefix applies the HasPrefix predicate on the "package_id" field.

func PackageIDHasSuffix

func PackageIDHasSuffix(v string) predicate.WingetConfigExclusion

PackageIDHasSuffix applies the HasSuffix predicate on the "package_id" field.

func PackageIDIn

func PackageIDIn(vs ...string) predicate.WingetConfigExclusion

PackageIDIn applies the In predicate on the "package_id" field.

func PackageIDLT

func PackageIDLT(v string) predicate.WingetConfigExclusion

PackageIDLT applies the LT predicate on the "package_id" field.

func PackageIDLTE

func PackageIDLTE(v string) predicate.WingetConfigExclusion

PackageIDLTE applies the LTE predicate on the "package_id" field.

func PackageIDNEQ

func PackageIDNEQ(v string) predicate.WingetConfigExclusion

PackageIDNEQ applies the NEQ predicate on the "package_id" field.

func PackageIDNotIn

func PackageIDNotIn(vs ...string) predicate.WingetConfigExclusion

PackageIDNotIn applies the NotIn predicate on the "package_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func When

When applies equality check predicate on the "when" field. It's identical to WhenEQ.

func WhenEQ

WhenEQ applies the EQ predicate on the "when" field.

func WhenGT

WhenGT applies the GT predicate on the "when" field.

func WhenGTE

WhenGTE applies the GTE predicate on the "when" field.

func WhenIn

WhenIn applies the In predicate on the "when" field.

func WhenIsNil

func WhenIsNil() predicate.WingetConfigExclusion

WhenIsNil applies the IsNil predicate on the "when" field.

func WhenLT

WhenLT applies the LT predicate on the "when" field.

func WhenLTE

WhenLTE applies the LTE predicate on the "when" field.

func WhenNEQ

WhenNEQ applies the NEQ predicate on the "when" field.

func WhenNotIn

func WhenNotIn(vs ...time.Time) predicate.WingetConfigExclusion

WhenNotIn applies the NotIn predicate on the "when" field.

func WhenNotNil

func WhenNotNil() predicate.WingetConfigExclusion

WhenNotNil applies the NotNil predicate on the "when" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the WingetConfigExclusion queries.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByOwnerField

func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption

ByOwnerField orders the results by owner field.

func ByPackageID

func ByPackageID(opts ...sql.OrderTermOption) OrderOption

ByPackageID orders the results by the package_id field.

func ByWhen

func ByWhen(opts ...sql.OrderTermOption) OrderOption

ByWhen orders the results by the when field.

Jump to