Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Branding) predicate.Branding
- func BugReportLink(v string) predicate.Branding
- func BugReportLinkContains(v string) predicate.Branding
- func BugReportLinkContainsFold(v string) predicate.Branding
- func BugReportLinkEQ(v string) predicate.Branding
- func BugReportLinkEqualFold(v string) predicate.Branding
- func BugReportLinkGT(v string) predicate.Branding
- func BugReportLinkGTE(v string) predicate.Branding
- func BugReportLinkHasPrefix(v string) predicate.Branding
- func BugReportLinkHasSuffix(v string) predicate.Branding
- func BugReportLinkIn(vs ...string) predicate.Branding
- func BugReportLinkIsNil() predicate.Branding
- func BugReportLinkLT(v string) predicate.Branding
- func BugReportLinkLTE(v string) predicate.Branding
- func BugReportLinkNEQ(v string) predicate.Branding
- func BugReportLinkNotIn(vs ...string) predicate.Branding
- func BugReportLinkNotNil() predicate.Branding
- func HelpLink(v string) predicate.Branding
- func HelpLinkContains(v string) predicate.Branding
- func HelpLinkContainsFold(v string) predicate.Branding
- func HelpLinkEQ(v string) predicate.Branding
- func HelpLinkEqualFold(v string) predicate.Branding
- func HelpLinkGT(v string) predicate.Branding
- func HelpLinkGTE(v string) predicate.Branding
- func HelpLinkHasPrefix(v string) predicate.Branding
- func HelpLinkHasSuffix(v string) predicate.Branding
- func HelpLinkIn(vs ...string) predicate.Branding
- func HelpLinkIsNil() predicate.Branding
- func HelpLinkLT(v string) predicate.Branding
- func HelpLinkLTE(v string) predicate.Branding
- func HelpLinkNEQ(v string) predicate.Branding
- func HelpLinkNotIn(vs ...string) predicate.Branding
- func HelpLinkNotNil() predicate.Branding
- func ID(id int) predicate.Branding
- func IDEQ(id int) predicate.Branding
- func IDGT(id int) predicate.Branding
- func IDGTE(id int) predicate.Branding
- func IDIn(ids ...int) predicate.Branding
- func IDLT(id int) predicate.Branding
- func IDLTE(id int) predicate.Branding
- func IDNEQ(id int) predicate.Branding
- func IDNotIn(ids ...int) predicate.Branding
- func LoginBackgroundImage(v string) predicate.Branding
- func LoginBackgroundImageContains(v string) predicate.Branding
- func LoginBackgroundImageContainsFold(v string) predicate.Branding
- func LoginBackgroundImageEQ(v string) predicate.Branding
- func LoginBackgroundImageEqualFold(v string) predicate.Branding
- func LoginBackgroundImageGT(v string) predicate.Branding
- func LoginBackgroundImageGTE(v string) predicate.Branding
- func LoginBackgroundImageHasPrefix(v string) predicate.Branding
- func LoginBackgroundImageHasSuffix(v string) predicate.Branding
- func LoginBackgroundImageIn(vs ...string) predicate.Branding
- func LoginBackgroundImageIsNil() predicate.Branding
- func LoginBackgroundImageLT(v string) predicate.Branding
- func LoginBackgroundImageLTE(v string) predicate.Branding
- func LoginBackgroundImageNEQ(v string) predicate.Branding
- func LoginBackgroundImageNotIn(vs ...string) predicate.Branding
- func LoginBackgroundImageNotNil() predicate.Branding
- func LoginWelcomeText(v string) predicate.Branding
- func LoginWelcomeTextContains(v string) predicate.Branding
- func LoginWelcomeTextContainsFold(v string) predicate.Branding
- func LoginWelcomeTextEQ(v string) predicate.Branding
- func LoginWelcomeTextEqualFold(v string) predicate.Branding
- func LoginWelcomeTextGT(v string) predicate.Branding
- func LoginWelcomeTextGTE(v string) predicate.Branding
- func LoginWelcomeTextHasPrefix(v string) predicate.Branding
- func LoginWelcomeTextHasSuffix(v string) predicate.Branding
- func LoginWelcomeTextIn(vs ...string) predicate.Branding
- func LoginWelcomeTextIsNil() predicate.Branding
- func LoginWelcomeTextLT(v string) predicate.Branding
- func LoginWelcomeTextLTE(v string) predicate.Branding
- func LoginWelcomeTextNEQ(v string) predicate.Branding
- func LoginWelcomeTextNotIn(vs ...string) predicate.Branding
- func LoginWelcomeTextNotNil() predicate.Branding
- func LogoLight(v string) predicate.Branding
- func LogoLightContains(v string) predicate.Branding
- func LogoLightContainsFold(v string) predicate.Branding
- func LogoLightEQ(v string) predicate.Branding
- func LogoLightEqualFold(v string) predicate.Branding
- func LogoLightGT(v string) predicate.Branding
- func LogoLightGTE(v string) predicate.Branding
- func LogoLightHasPrefix(v string) predicate.Branding
- func LogoLightHasSuffix(v string) predicate.Branding
- func LogoLightIn(vs ...string) predicate.Branding
- func LogoLightIsNil() predicate.Branding
- func LogoLightLT(v string) predicate.Branding
- func LogoLightLTE(v string) predicate.Branding
- func LogoLightNEQ(v string) predicate.Branding
- func LogoLightNotIn(vs ...string) predicate.Branding
- func LogoLightNotNil() predicate.Branding
- func LogoSmall(v string) predicate.Branding
- func LogoSmallContains(v string) predicate.Branding
- func LogoSmallContainsFold(v string) predicate.Branding
- func LogoSmallEQ(v string) predicate.Branding
- func LogoSmallEqualFold(v string) predicate.Branding
- func LogoSmallGT(v string) predicate.Branding
- func LogoSmallGTE(v string) predicate.Branding
- func LogoSmallHasPrefix(v string) predicate.Branding
- func LogoSmallHasSuffix(v string) predicate.Branding
- func LogoSmallIn(vs ...string) predicate.Branding
- func LogoSmallIsNil() predicate.Branding
- func LogoSmallLT(v string) predicate.Branding
- func LogoSmallLTE(v string) predicate.Branding
- func LogoSmallNEQ(v string) predicate.Branding
- func LogoSmallNotIn(vs ...string) predicate.Branding
- func LogoSmallNotNil() predicate.Branding
- func Not(p predicate.Branding) predicate.Branding
- func Or(predicates ...predicate.Branding) predicate.Branding
- func PrimaryColor(v string) predicate.Branding
- func PrimaryColorContains(v string) predicate.Branding
- func PrimaryColorContainsFold(v string) predicate.Branding
- func PrimaryColorEQ(v string) predicate.Branding
- func PrimaryColorEqualFold(v string) predicate.Branding
- func PrimaryColorGT(v string) predicate.Branding
- func PrimaryColorGTE(v string) predicate.Branding
- func PrimaryColorHasPrefix(v string) predicate.Branding
- func PrimaryColorHasSuffix(v string) predicate.Branding
- func PrimaryColorIn(vs ...string) predicate.Branding
- func PrimaryColorIsNil() predicate.Branding
- func PrimaryColorLT(v string) predicate.Branding
- func PrimaryColorLTE(v string) predicate.Branding
- func PrimaryColorNEQ(v string) predicate.Branding
- func PrimaryColorNotIn(vs ...string) predicate.Branding
- func PrimaryColorNotNil() predicate.Branding
- func ProductName(v string) predicate.Branding
- func ProductNameContains(v string) predicate.Branding
- func ProductNameContainsFold(v string) predicate.Branding
- func ProductNameEQ(v string) predicate.Branding
- func ProductNameEqualFold(v string) predicate.Branding
- func ProductNameGT(v string) predicate.Branding
- func ProductNameGTE(v string) predicate.Branding
- func ProductNameHasPrefix(v string) predicate.Branding
- func ProductNameHasSuffix(v string) predicate.Branding
- func ProductNameIn(vs ...string) predicate.Branding
- func ProductNameIsNil() predicate.Branding
- func ProductNameLT(v string) predicate.Branding
- func ProductNameLTE(v string) predicate.Branding
- func ProductNameNEQ(v string) predicate.Branding
- func ProductNameNotIn(vs ...string) predicate.Branding
- func ProductNameNotNil() predicate.Branding
- func ShowVersion(v bool) predicate.Branding
- func ShowVersionEQ(v bool) predicate.Branding
- func ShowVersionIsNil() predicate.Branding
- func ShowVersionNEQ(v bool) predicate.Branding
- func ShowVersionNotNil() predicate.Branding
- func ValidColumn(column string) bool
- type OrderOption
- func ByBugReportLink(opts ...sql.OrderTermOption) OrderOption
- func ByHelpLink(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByLoginBackgroundImage(opts ...sql.OrderTermOption) OrderOption
- func ByLoginWelcomeText(opts ...sql.OrderTermOption) OrderOption
- func ByLogoLight(opts ...sql.OrderTermOption) OrderOption
- func ByLogoSmall(opts ...sql.OrderTermOption) OrderOption
- func ByPrimaryColor(opts ...sql.OrderTermOption) OrderOption
- func ByProductName(opts ...sql.OrderTermOption) OrderOption
- func ByShowVersion(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the branding type in the database. Label = "branding" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldLogoLight holds the string denoting the logo_light field in the database. FieldLogoLight = "logo_light" // FieldLogoSmall holds the string denoting the logo_small field in the database. FieldLogoSmall = "logo_small" // FieldPrimaryColor holds the string denoting the primary_color field in the database. FieldPrimaryColor = "primary_color" // FieldProductName holds the string denoting the product_name field in the database. FieldProductName = "product_name" // FieldLoginBackgroundImage holds the string denoting the login_background_image field in the database. FieldLoginBackgroundImage = "login_background_image" // FieldLoginWelcomeText holds the string denoting the login_welcome_text field in the database. FieldLoginWelcomeText = "login_welcome_text" // FieldShowVersion holds the string denoting the show_version field in the database. FieldShowVersion = "show_version" // FieldBugReportLink holds the string denoting the bug_report_link field in the database. FieldBugReportLink = "bug_report_link" // FieldHelpLink holds the string denoting the help_link field in the database. FieldHelpLink = "help_link" // Table holds the table name of the branding in the database. Table = "brandings" )
Variables ¶
var ( // DefaultPrimaryColor holds the default value on creation for the "primary_color" field. DefaultPrimaryColor string // DefaultProductName holds the default value on creation for the "product_name" field. DefaultProductName string // DefaultShowVersion holds the default value on creation for the "show_version" field. DefaultShowVersion bool // DefaultBugReportLink holds the default value on creation for the "bug_report_link" field. DefaultBugReportLink string // DefaultHelpLink holds the default value on creation for the "help_link" field. DefaultHelpLink string )
var Columns = []string{ FieldID, FieldLogoLight, FieldLogoSmall, FieldPrimaryColor, FieldProductName, FieldLoginBackgroundImage, FieldLoginWelcomeText, FieldShowVersion, FieldBugReportLink, FieldHelpLink, }
Columns holds all SQL columns for branding fields.
Functions ¶
func BugReportLink ¶
BugReportLink applies equality check predicate on the "bug_report_link" field. It's identical to BugReportLinkEQ.
func BugReportLinkContains ¶
BugReportLinkContains applies the Contains predicate on the "bug_report_link" field.
func BugReportLinkContainsFold ¶
BugReportLinkContainsFold applies the ContainsFold predicate on the "bug_report_link" field.
func BugReportLinkEQ ¶
BugReportLinkEQ applies the EQ predicate on the "bug_report_link" field.
func BugReportLinkEqualFold ¶
BugReportLinkEqualFold applies the EqualFold predicate on the "bug_report_link" field.
func BugReportLinkGT ¶
BugReportLinkGT applies the GT predicate on the "bug_report_link" field.
func BugReportLinkGTE ¶
BugReportLinkGTE applies the GTE predicate on the "bug_report_link" field.
func BugReportLinkHasPrefix ¶
BugReportLinkHasPrefix applies the HasPrefix predicate on the "bug_report_link" field.
func BugReportLinkHasSuffix ¶
BugReportLinkHasSuffix applies the HasSuffix predicate on the "bug_report_link" field.
func BugReportLinkIn ¶
BugReportLinkIn applies the In predicate on the "bug_report_link" field.
func BugReportLinkIsNil ¶
BugReportLinkIsNil applies the IsNil predicate on the "bug_report_link" field.
func BugReportLinkLT ¶
BugReportLinkLT applies the LT predicate on the "bug_report_link" field.
func BugReportLinkLTE ¶
BugReportLinkLTE applies the LTE predicate on the "bug_report_link" field.
func BugReportLinkNEQ ¶
BugReportLinkNEQ applies the NEQ predicate on the "bug_report_link" field.
func BugReportLinkNotIn ¶
BugReportLinkNotIn applies the NotIn predicate on the "bug_report_link" field.
func BugReportLinkNotNil ¶
BugReportLinkNotNil applies the NotNil predicate on the "bug_report_link" field.
func HelpLink ¶
HelpLink applies equality check predicate on the "help_link" field. It's identical to HelpLinkEQ.
func HelpLinkContains ¶
HelpLinkContains applies the Contains predicate on the "help_link" field.
func HelpLinkContainsFold ¶
HelpLinkContainsFold applies the ContainsFold predicate on the "help_link" field.
func HelpLinkEQ ¶
HelpLinkEQ applies the EQ predicate on the "help_link" field.
func HelpLinkEqualFold ¶
HelpLinkEqualFold applies the EqualFold predicate on the "help_link" field.
func HelpLinkGT ¶
HelpLinkGT applies the GT predicate on the "help_link" field.
func HelpLinkGTE ¶
HelpLinkGTE applies the GTE predicate on the "help_link" field.
func HelpLinkHasPrefix ¶
HelpLinkHasPrefix applies the HasPrefix predicate on the "help_link" field.
func HelpLinkHasSuffix ¶
HelpLinkHasSuffix applies the HasSuffix predicate on the "help_link" field.
func HelpLinkIn ¶
HelpLinkIn applies the In predicate on the "help_link" field.
func HelpLinkIsNil ¶
HelpLinkIsNil applies the IsNil predicate on the "help_link" field.
func HelpLinkLT ¶
HelpLinkLT applies the LT predicate on the "help_link" field.
func HelpLinkLTE ¶
HelpLinkLTE applies the LTE predicate on the "help_link" field.
func HelpLinkNEQ ¶
HelpLinkNEQ applies the NEQ predicate on the "help_link" field.
func HelpLinkNotIn ¶
HelpLinkNotIn applies the NotIn predicate on the "help_link" field.
func HelpLinkNotNil ¶
HelpLinkNotNil applies the NotNil predicate on the "help_link" field.
func LoginBackgroundImage ¶
LoginBackgroundImage applies equality check predicate on the "login_background_image" field. It's identical to LoginBackgroundImageEQ.
func LoginBackgroundImageContains ¶
LoginBackgroundImageContains applies the Contains predicate on the "login_background_image" field.
func LoginBackgroundImageContainsFold ¶
LoginBackgroundImageContainsFold applies the ContainsFold predicate on the "login_background_image" field.
func LoginBackgroundImageEQ ¶
LoginBackgroundImageEQ applies the EQ predicate on the "login_background_image" field.
func LoginBackgroundImageEqualFold ¶
LoginBackgroundImageEqualFold applies the EqualFold predicate on the "login_background_image" field.
func LoginBackgroundImageGT ¶
LoginBackgroundImageGT applies the GT predicate on the "login_background_image" field.
func LoginBackgroundImageGTE ¶
LoginBackgroundImageGTE applies the GTE predicate on the "login_background_image" field.
func LoginBackgroundImageHasPrefix ¶
LoginBackgroundImageHasPrefix applies the HasPrefix predicate on the "login_background_image" field.
func LoginBackgroundImageHasSuffix ¶
LoginBackgroundImageHasSuffix applies the HasSuffix predicate on the "login_background_image" field.
func LoginBackgroundImageIn ¶
LoginBackgroundImageIn applies the In predicate on the "login_background_image" field.
func LoginBackgroundImageIsNil ¶
LoginBackgroundImageIsNil applies the IsNil predicate on the "login_background_image" field.
func LoginBackgroundImageLT ¶
LoginBackgroundImageLT applies the LT predicate on the "login_background_image" field.
func LoginBackgroundImageLTE ¶
LoginBackgroundImageLTE applies the LTE predicate on the "login_background_image" field.
func LoginBackgroundImageNEQ ¶
LoginBackgroundImageNEQ applies the NEQ predicate on the "login_background_image" field.
func LoginBackgroundImageNotIn ¶
LoginBackgroundImageNotIn applies the NotIn predicate on the "login_background_image" field.
func LoginBackgroundImageNotNil ¶
LoginBackgroundImageNotNil applies the NotNil predicate on the "login_background_image" field.
func LoginWelcomeText ¶
LoginWelcomeText applies equality check predicate on the "login_welcome_text" field. It's identical to LoginWelcomeTextEQ.
func LoginWelcomeTextContains ¶
LoginWelcomeTextContains applies the Contains predicate on the "login_welcome_text" field.
func LoginWelcomeTextContainsFold ¶
LoginWelcomeTextContainsFold applies the ContainsFold predicate on the "login_welcome_text" field.
func LoginWelcomeTextEQ ¶
LoginWelcomeTextEQ applies the EQ predicate on the "login_welcome_text" field.
func LoginWelcomeTextEqualFold ¶
LoginWelcomeTextEqualFold applies the EqualFold predicate on the "login_welcome_text" field.
func LoginWelcomeTextGT ¶
LoginWelcomeTextGT applies the GT predicate on the "login_welcome_text" field.
func LoginWelcomeTextGTE ¶
LoginWelcomeTextGTE applies the GTE predicate on the "login_welcome_text" field.
func LoginWelcomeTextHasPrefix ¶
LoginWelcomeTextHasPrefix applies the HasPrefix predicate on the "login_welcome_text" field.
func LoginWelcomeTextHasSuffix ¶
LoginWelcomeTextHasSuffix applies the HasSuffix predicate on the "login_welcome_text" field.
func LoginWelcomeTextIn ¶
LoginWelcomeTextIn applies the In predicate on the "login_welcome_text" field.
func LoginWelcomeTextIsNil ¶
LoginWelcomeTextIsNil applies the IsNil predicate on the "login_welcome_text" field.
func LoginWelcomeTextLT ¶
LoginWelcomeTextLT applies the LT predicate on the "login_welcome_text" field.
func LoginWelcomeTextLTE ¶
LoginWelcomeTextLTE applies the LTE predicate on the "login_welcome_text" field.
func LoginWelcomeTextNEQ ¶
LoginWelcomeTextNEQ applies the NEQ predicate on the "login_welcome_text" field.
func LoginWelcomeTextNotIn ¶
LoginWelcomeTextNotIn applies the NotIn predicate on the "login_welcome_text" field.
func LoginWelcomeTextNotNil ¶
LoginWelcomeTextNotNil applies the NotNil predicate on the "login_welcome_text" field.
func LogoLight ¶
LogoLight applies equality check predicate on the "logo_light" field. It's identical to LogoLightEQ.
func LogoLightContains ¶
LogoLightContains applies the Contains predicate on the "logo_light" field.
func LogoLightContainsFold ¶
LogoLightContainsFold applies the ContainsFold predicate on the "logo_light" field.
func LogoLightEQ ¶
LogoLightEQ applies the EQ predicate on the "logo_light" field.
func LogoLightEqualFold ¶
LogoLightEqualFold applies the EqualFold predicate on the "logo_light" field.
func LogoLightGT ¶
LogoLightGT applies the GT predicate on the "logo_light" field.
func LogoLightGTE ¶
LogoLightGTE applies the GTE predicate on the "logo_light" field.
func LogoLightHasPrefix ¶
LogoLightHasPrefix applies the HasPrefix predicate on the "logo_light" field.
func LogoLightHasSuffix ¶
LogoLightHasSuffix applies the HasSuffix predicate on the "logo_light" field.
func LogoLightIn ¶
LogoLightIn applies the In predicate on the "logo_light" field.
func LogoLightIsNil ¶
LogoLightIsNil applies the IsNil predicate on the "logo_light" field.
func LogoLightLT ¶
LogoLightLT applies the LT predicate on the "logo_light" field.
func LogoLightLTE ¶
LogoLightLTE applies the LTE predicate on the "logo_light" field.
func LogoLightNEQ ¶
LogoLightNEQ applies the NEQ predicate on the "logo_light" field.
func LogoLightNotIn ¶
LogoLightNotIn applies the NotIn predicate on the "logo_light" field.
func LogoLightNotNil ¶
LogoLightNotNil applies the NotNil predicate on the "logo_light" field.
func LogoSmall ¶
LogoSmall applies equality check predicate on the "logo_small" field. It's identical to LogoSmallEQ.
func LogoSmallContains ¶
LogoSmallContains applies the Contains predicate on the "logo_small" field.
func LogoSmallContainsFold ¶
LogoSmallContainsFold applies the ContainsFold predicate on the "logo_small" field.
func LogoSmallEQ ¶
LogoSmallEQ applies the EQ predicate on the "logo_small" field.
func LogoSmallEqualFold ¶
LogoSmallEqualFold applies the EqualFold predicate on the "logo_small" field.
func LogoSmallGT ¶
LogoSmallGT applies the GT predicate on the "logo_small" field.
func LogoSmallGTE ¶
LogoSmallGTE applies the GTE predicate on the "logo_small" field.
func LogoSmallHasPrefix ¶
LogoSmallHasPrefix applies the HasPrefix predicate on the "logo_small" field.
func LogoSmallHasSuffix ¶
LogoSmallHasSuffix applies the HasSuffix predicate on the "logo_small" field.
func LogoSmallIn ¶
LogoSmallIn applies the In predicate on the "logo_small" field.
func LogoSmallIsNil ¶
LogoSmallIsNil applies the IsNil predicate on the "logo_small" field.
func LogoSmallLT ¶
LogoSmallLT applies the LT predicate on the "logo_small" field.
func LogoSmallLTE ¶
LogoSmallLTE applies the LTE predicate on the "logo_small" field.
func LogoSmallNEQ ¶
LogoSmallNEQ applies the NEQ predicate on the "logo_small" field.
func LogoSmallNotIn ¶
LogoSmallNotIn applies the NotIn predicate on the "logo_small" field.
func LogoSmallNotNil ¶
LogoSmallNotNil applies the NotNil predicate on the "logo_small" field.
func PrimaryColor ¶
PrimaryColor applies equality check predicate on the "primary_color" field. It's identical to PrimaryColorEQ.
func PrimaryColorContains ¶
PrimaryColorContains applies the Contains predicate on the "primary_color" field.
func PrimaryColorContainsFold ¶
PrimaryColorContainsFold applies the ContainsFold predicate on the "primary_color" field.
func PrimaryColorEQ ¶
PrimaryColorEQ applies the EQ predicate on the "primary_color" field.
func PrimaryColorEqualFold ¶
PrimaryColorEqualFold applies the EqualFold predicate on the "primary_color" field.
func PrimaryColorGT ¶
PrimaryColorGT applies the GT predicate on the "primary_color" field.
func PrimaryColorGTE ¶
PrimaryColorGTE applies the GTE predicate on the "primary_color" field.
func PrimaryColorHasPrefix ¶
PrimaryColorHasPrefix applies the HasPrefix predicate on the "primary_color" field.
func PrimaryColorHasSuffix ¶
PrimaryColorHasSuffix applies the HasSuffix predicate on the "primary_color" field.
func PrimaryColorIn ¶
PrimaryColorIn applies the In predicate on the "primary_color" field.
func PrimaryColorIsNil ¶
PrimaryColorIsNil applies the IsNil predicate on the "primary_color" field.
func PrimaryColorLT ¶
PrimaryColorLT applies the LT predicate on the "primary_color" field.
func PrimaryColorLTE ¶
PrimaryColorLTE applies the LTE predicate on the "primary_color" field.
func PrimaryColorNEQ ¶
PrimaryColorNEQ applies the NEQ predicate on the "primary_color" field.
func PrimaryColorNotIn ¶
PrimaryColorNotIn applies the NotIn predicate on the "primary_color" field.
func PrimaryColorNotNil ¶
PrimaryColorNotNil applies the NotNil predicate on the "primary_color" field.
func ProductName ¶
ProductName applies equality check predicate on the "product_name" field. It's identical to ProductNameEQ.
func ProductNameContains ¶
ProductNameContains applies the Contains predicate on the "product_name" field.
func ProductNameContainsFold ¶
ProductNameContainsFold applies the ContainsFold predicate on the "product_name" field.
func ProductNameEQ ¶
ProductNameEQ applies the EQ predicate on the "product_name" field.
func ProductNameEqualFold ¶
ProductNameEqualFold applies the EqualFold predicate on the "product_name" field.
func ProductNameGT ¶
ProductNameGT applies the GT predicate on the "product_name" field.
func ProductNameGTE ¶
ProductNameGTE applies the GTE predicate on the "product_name" field.
func ProductNameHasPrefix ¶
ProductNameHasPrefix applies the HasPrefix predicate on the "product_name" field.
func ProductNameHasSuffix ¶
ProductNameHasSuffix applies the HasSuffix predicate on the "product_name" field.
func ProductNameIn ¶
ProductNameIn applies the In predicate on the "product_name" field.
func ProductNameIsNil ¶
ProductNameIsNil applies the IsNil predicate on the "product_name" field.
func ProductNameLT ¶
ProductNameLT applies the LT predicate on the "product_name" field.
func ProductNameLTE ¶
ProductNameLTE applies the LTE predicate on the "product_name" field.
func ProductNameNEQ ¶
ProductNameNEQ applies the NEQ predicate on the "product_name" field.
func ProductNameNotIn ¶
ProductNameNotIn applies the NotIn predicate on the "product_name" field.
func ProductNameNotNil ¶
ProductNameNotNil applies the NotNil predicate on the "product_name" field.
func ShowVersion ¶
ShowVersion applies equality check predicate on the "show_version" field. It's identical to ShowVersionEQ.
func ShowVersionEQ ¶
ShowVersionEQ applies the EQ predicate on the "show_version" field.
func ShowVersionIsNil ¶
ShowVersionIsNil applies the IsNil predicate on the "show_version" field.
func ShowVersionNEQ ¶
ShowVersionNEQ applies the NEQ predicate on the "show_version" field.
func ShowVersionNotNil ¶
ShowVersionNotNil applies the NotNil predicate on the "show_version" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Branding queries.
func ByBugReportLink ¶
func ByBugReportLink(opts ...sql.OrderTermOption) OrderOption
ByBugReportLink orders the results by the bug_report_link field.
func ByHelpLink ¶
func ByHelpLink(opts ...sql.OrderTermOption) OrderOption
ByHelpLink orders the results by the help_link field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByLoginBackgroundImage ¶
func ByLoginBackgroundImage(opts ...sql.OrderTermOption) OrderOption
ByLoginBackgroundImage orders the results by the login_background_image field.
func ByLoginWelcomeText ¶
func ByLoginWelcomeText(opts ...sql.OrderTermOption) OrderOption
ByLoginWelcomeText orders the results by the login_welcome_text field.
func ByLogoLight ¶
func ByLogoLight(opts ...sql.OrderTermOption) OrderOption
ByLogoLight orders the results by the logo_light field.
func ByLogoSmall ¶
func ByLogoSmall(opts ...sql.OrderTermOption) OrderOption
ByLogoSmall orders the results by the logo_small field.
func ByPrimaryColor ¶
func ByPrimaryColor(opts ...sql.OrderTermOption) OrderOption
ByPrimaryColor orders the results by the primary_color field.
func ByProductName ¶
func ByProductName(opts ...sql.OrderTermOption) OrderOption
ByProductName orders the results by the product_name field.
func ByShowVersion ¶
func ByShowVersion(opts ...sql.OrderTermOption) OrderOption
ByShowVersion orders the results by the show_version field.