Documentation
¶
Index ¶
- type Agent
- type Antivirus
- type App
- type Authentication
- type Branding
- type Certificate
- type Computer
- type Deployment
- type EnrollmentToken
- type LogicalDisk
- type ManagedPackage
- type MemorySlot
- type Metadata
- type Monitor
- type Netbird
- type NetbirdSettings
- type NetworkAdapter
- type OperatingSystem
- type OrgMetadata
- type PhysicalDisk
- type Printer
- type Profile
- type ProfileIssue
- type RecoveryCode
- type Release
- type Revocation
- type Rustdesk
- type Server
- type Sessions
- type Settings
- type Share
- type Site
- type SoftwareAssignment
- type SoftwareCatalog
- type SoftwareInstallLog
- type SoftwarePackage
- type SoftwareRepo
- type SystemUpdate
- type Tag
- type Task
- type TaskReport
- type Tenant
- type Update
- type User
- type UserTenant
- type WingetConfigExclusion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Authentication ¶
Authentication holds the schema definition for the Authentication entity.
func (Authentication) Fields ¶
func (Authentication) Fields() []ent.Field
Fields of the Authentication.
type Branding ¶
Branding holds the schema definition for the Branding entity. This stores global provider branding settings that apply across all tenants.
type Certificate ¶
Certificate holds the schema definition for the Certificate entity.
type Deployment ¶
Deployment holds the schema definition for the Deployment entity.
type EnrollmentToken ¶
EnrollmentToken holds the schema definition for the EnrollmentToken entity. Enrollment tokens allow tenant admins to securely register agents to their tenant.
func (EnrollmentToken) Edges ¶
func (EnrollmentToken) Edges() []ent.Edge
Edges of the EnrollmentToken.
func (EnrollmentToken) Fields ¶
func (EnrollmentToken) Fields() []ent.Field
Fields of the EnrollmentToken.
type LogicalDisk ¶
Logical Disk holds the schema definition for the Logical Disk entity.
type ManagedPackage ¶
ManagedPackage holds the schema definition for the ManagedPackage entity.
func (ManagedPackage) Fields ¶
func (ManagedPackage) Fields() []ent.Field
Fields of the ManagedPackage.
func (ManagedPackage) Indexes ¶
func (ManagedPackage) Indexes() []ent.Index
Indexes of the ManagedPackage.
type MemorySlot ¶
MemorySlot holds the schema definition for the MemorySlot entity.
type NetbirdSettings ¶
NetbirdSettings holds the schema definition for the NetbirdSettings entity.
func (NetbirdSettings) Edges ¶
func (NetbirdSettings) Edges() []ent.Edge
Edges of the NetbirdSettings.
func (NetbirdSettings) Fields ¶
func (NetbirdSettings) Fields() []ent.Field
Fields of the NetbirdSettings.
type NetworkAdapter ¶
NetworkAdapter holds the schema definition for the NetworkAdapter entity.
func (NetworkAdapter) Fields ¶
func (NetworkAdapter) Fields() []ent.Field
Fields of the NetworkAdapter.
type OperatingSystem ¶
OperatingSystem holds the schema definition for the OperatingSystem entity.
func (OperatingSystem) Edges ¶
func (OperatingSystem) Edges() []ent.Edge
Edges of the OperatingSystem.
func (OperatingSystem) Fields ¶
func (OperatingSystem) Fields() []ent.Field
Fields of the OperatingSystem.
type OrgMetadata ¶
OrgMetadata holds the schema definition for the OrgMetadata entity.
type PhysicalDisk ¶
Physical Disk holds the schema definition for the Physical Disk entity.
type ProfileIssue ¶
ProfileIssue holds the schema definition for the ProfileIssue entity.
type RecoveryCode ¶
RecoveryCode holds the schema definition for the RecoveryCode entity.
func (RecoveryCode) Edges ¶
func (RecoveryCode) Edges() []ent.Edge
type Revocation ¶
Revocation holds the schema definition for the Revocation entity.
type SoftwareAssignment ¶
SoftwareAssignment holds the schema definition for the SoftwareAssignment entity.
func (SoftwareAssignment) Edges ¶
func (SoftwareAssignment) Edges() []ent.Edge
Edges of the SoftwareAssignment.
func (SoftwareAssignment) Fields ¶
func (SoftwareAssignment) Fields() []ent.Field
Fields of the SoftwareAssignment.
func (SoftwareAssignment) Indexes ¶
func (SoftwareAssignment) Indexes() []ent.Index
Indexes of the SoftwareAssignment.
type SoftwareCatalog ¶
SoftwareCatalog holds the schema definition for the SoftwareCatalog entity.
func (SoftwareCatalog) Edges ¶
func (SoftwareCatalog) Edges() []ent.Edge
Edges of the SoftwareCatalog.
func (SoftwareCatalog) Fields ¶
func (SoftwareCatalog) Fields() []ent.Field
Fields of the SoftwareCatalog.
func (SoftwareCatalog) Indexes ¶
func (SoftwareCatalog) Indexes() []ent.Index
Indexes of the SoftwareCatalog.
type SoftwareInstallLog ¶
SoftwareInstallLog holds the schema definition for the SoftwareInstallLog entity.
func (SoftwareInstallLog) Edges ¶
func (SoftwareInstallLog) Edges() []ent.Edge
Edges of the SoftwareInstallLog.
func (SoftwareInstallLog) Fields ¶
func (SoftwareInstallLog) Fields() []ent.Field
Fields of the SoftwareInstallLog.
func (SoftwareInstallLog) Indexes ¶
func (SoftwareInstallLog) Indexes() []ent.Index
Indexes of the SoftwareInstallLog.
type SoftwarePackage ¶
SoftwarePackage holds the schema definition for the SoftwarePackage entity.
func (SoftwarePackage) Fields ¶
func (SoftwarePackage) Fields() []ent.Field
Fields of the SoftwarePackage.
type SoftwareRepo ¶
SoftwareRepo holds the schema definition for the SoftwareRepo entity.
func (SoftwareRepo) Indexes ¶
func (SoftwareRepo) Indexes() []ent.Index
Indexes of the SoftwareRepo.
type SystemUpdate ¶
SystemUpdate holds the schema definition for the SystemUpdate entity.
type TaskReport ¶
TaskReport holds the schema definition for the Task entity.
type UserTenant ¶
UserTenant holds the schema definition for the User-Tenant relationship. This is the junction table that connects users to tenants with their role.
type WingetConfigExclusion ¶
holds the schema definition for the WingetConfigExclusion entity.
func (WingetConfigExclusion) Edges ¶
func (WingetConfigExclusion) Edges() []ent.Edge
Edges of the WingetConfigExclusion.
func (WingetConfigExclusion) Fields ¶
func (WingetConfigExclusion) Fields() []ent.Field
Fields of the WingetConfigExclusion.
Source Files
¶
- agent.go
- antivirus.go
- app.go
- auth.go
- branding.go
- certificate.go
- computer.go
- deploy.go
- enrollmenttoken.go
- logicaldisk.go
- managedpackage.go
- memoryslot.go
- metadata.go
- monitor.go
- netbird.go
- netbirdsettings.go
- networkadapter.go
- operatingsystem.go
- orgmetadata.go
- physicaldisk.go
- printer.go
- profile.go
- profileissue.go
- recoverycodes.go
- release.go
- revocation.go
- rustdesk.go
- server.go
- sessions.go
- settings.go
- share.go
- site.go
- softwareassignment.go
- softwarecatalog.go
- softwareinstalllog.go
- softwarepackage.go
- softwarerepo.go
- systemupdate.go
- tag.go
- task.go
- taskreport.go
- tenant.go
- update.go
- user.go
- usertenant.go
- wingetcfgexclusions.go