Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.SoftwarePackage) predicate.SoftwarePackage
- func Arch(v string) predicate.SoftwarePackage
- func ArchContains(v string) predicate.SoftwarePackage
- func ArchContainsFold(v string) predicate.SoftwarePackage
- func ArchEQ(v string) predicate.SoftwarePackage
- func ArchEqualFold(v string) predicate.SoftwarePackage
- func ArchGT(v string) predicate.SoftwarePackage
- func ArchGTE(v string) predicate.SoftwarePackage
- func ArchHasPrefix(v string) predicate.SoftwarePackage
- func ArchHasSuffix(v string) predicate.SoftwarePackage
- func ArchIn(vs ...string) predicate.SoftwarePackage
- func ArchIsNil() predicate.SoftwarePackage
- func ArchLT(v string) predicate.SoftwarePackage
- func ArchLTE(v string) predicate.SoftwarePackage
- func ArchNEQ(v string) predicate.SoftwarePackage
- func ArchNotIn(vs ...string) predicate.SoftwarePackage
- func ArchNotNil() predicate.SoftwarePackage
- func Branch(v string) predicate.SoftwarePackage
- func BranchContains(v string) predicate.SoftwarePackage
- func BranchContainsFold(v string) predicate.SoftwarePackage
- func BranchEQ(v string) predicate.SoftwarePackage
- func BranchEqualFold(v string) predicate.SoftwarePackage
- func BranchGT(v string) predicate.SoftwarePackage
- func BranchGTE(v string) predicate.SoftwarePackage
- func BranchHasPrefix(v string) predicate.SoftwarePackage
- func BranchHasSuffix(v string) predicate.SoftwarePackage
- func BranchIn(vs ...string) predicate.SoftwarePackage
- func BranchIsNil() predicate.SoftwarePackage
- func BranchLT(v string) predicate.SoftwarePackage
- func BranchLTE(v string) predicate.SoftwarePackage
- func BranchNEQ(v string) predicate.SoftwarePackage
- func BranchNotIn(vs ...string) predicate.SoftwarePackage
- func BranchNotNil() predicate.SoftwarePackage
- func BrewType(v string) predicate.SoftwarePackage
- func BrewTypeContains(v string) predicate.SoftwarePackage
- func BrewTypeContainsFold(v string) predicate.SoftwarePackage
- func BrewTypeEQ(v string) predicate.SoftwarePackage
- func BrewTypeEqualFold(v string) predicate.SoftwarePackage
- func BrewTypeGT(v string) predicate.SoftwarePackage
- func BrewTypeGTE(v string) predicate.SoftwarePackage
- func BrewTypeHasPrefix(v string) predicate.SoftwarePackage
- func BrewTypeHasSuffix(v string) predicate.SoftwarePackage
- func BrewTypeIn(vs ...string) predicate.SoftwarePackage
- func BrewTypeIsNil() predicate.SoftwarePackage
- func BrewTypeLT(v string) predicate.SoftwarePackage
- func BrewTypeLTE(v string) predicate.SoftwarePackage
- func BrewTypeNEQ(v string) predicate.SoftwarePackage
- func BrewTypeNotIn(vs ...string) predicate.SoftwarePackage
- func BrewTypeNotNil() predicate.SoftwarePackage
- func ID(id uuid.UUID) predicate.SoftwarePackage
- func IDEQ(id uuid.UUID) predicate.SoftwarePackage
- func IDGT(id uuid.UUID) predicate.SoftwarePackage
- func IDGTE(id uuid.UUID) predicate.SoftwarePackage
- func IDIn(ids ...uuid.UUID) predicate.SoftwarePackage
- func IDLT(id uuid.UUID) predicate.SoftwarePackage
- func IDLTE(id uuid.UUID) predicate.SoftwarePackage
- func IDNEQ(id uuid.UUID) predicate.SoftwarePackage
- func IDNotIn(ids ...uuid.UUID) predicate.SoftwarePackage
- func Name(v string) predicate.SoftwarePackage
- func NameContains(v string) predicate.SoftwarePackage
- func NameContainsFold(v string) predicate.SoftwarePackage
- func NameEQ(v string) predicate.SoftwarePackage
- func NameEqualFold(v string) predicate.SoftwarePackage
- func NameGT(v string) predicate.SoftwarePackage
- func NameGTE(v string) predicate.SoftwarePackage
- func NameHasPrefix(v string) predicate.SoftwarePackage
- func NameHasSuffix(v string) predicate.SoftwarePackage
- func NameIn(vs ...string) predicate.SoftwarePackage
- func NameLT(v string) predicate.SoftwarePackage
- func NameLTE(v string) predicate.SoftwarePackage
- func NameNEQ(v string) predicate.SoftwarePackage
- func NameNotIn(vs ...string) predicate.SoftwarePackage
- func Not(p predicate.SoftwarePackage) predicate.SoftwarePackage
- func Or(predicates ...predicate.SoftwarePackage) predicate.SoftwarePackage
- func PackageID(v string) predicate.SoftwarePackage
- func PackageIDContains(v string) predicate.SoftwarePackage
- func PackageIDContainsFold(v string) predicate.SoftwarePackage
- func PackageIDEQ(v string) predicate.SoftwarePackage
- func PackageIDEqualFold(v string) predicate.SoftwarePackage
- func PackageIDGT(v string) predicate.SoftwarePackage
- func PackageIDGTE(v string) predicate.SoftwarePackage
- func PackageIDHasPrefix(v string) predicate.SoftwarePackage
- func PackageIDHasSuffix(v string) predicate.SoftwarePackage
- func PackageIDIn(vs ...string) predicate.SoftwarePackage
- func PackageIDLT(v string) predicate.SoftwarePackage
- func PackageIDLTE(v string) predicate.SoftwarePackage
- func PackageIDNEQ(v string) predicate.SoftwarePackage
- func PackageIDNotIn(vs ...string) predicate.SoftwarePackage
- func Source(v string) predicate.SoftwarePackage
- func SourceContains(v string) predicate.SoftwarePackage
- func SourceContainsFold(v string) predicate.SoftwarePackage
- func SourceEQ(v string) predicate.SoftwarePackage
- func SourceEqualFold(v string) predicate.SoftwarePackage
- func SourceGT(v string) predicate.SoftwarePackage
- func SourceGTE(v string) predicate.SoftwarePackage
- func SourceHasPrefix(v string) predicate.SoftwarePackage
- func SourceHasSuffix(v string) predicate.SoftwarePackage
- func SourceIn(vs ...string) predicate.SoftwarePackage
- func SourceLT(v string) predicate.SoftwarePackage
- func SourceLTE(v string) predicate.SoftwarePackage
- func SourceNEQ(v string) predicate.SoftwarePackage
- func SourceNotIn(vs ...string) predicate.SoftwarePackage
- func ValidColumn(column string) bool
- func Verified(v bool) predicate.SoftwarePackage
- func VerifiedEQ(v bool) predicate.SoftwarePackage
- func VerifiedIsNil() predicate.SoftwarePackage
- func VerifiedNEQ(v bool) predicate.SoftwarePackage
- func VerifiedNotNil() predicate.SoftwarePackage
- func Version(v string) predicate.SoftwarePackage
- func VersionContains(v string) predicate.SoftwarePackage
- func VersionContainsFold(v string) predicate.SoftwarePackage
- func VersionEQ(v string) predicate.SoftwarePackage
- func VersionEqualFold(v string) predicate.SoftwarePackage
- func VersionGT(v string) predicate.SoftwarePackage
- func VersionGTE(v string) predicate.SoftwarePackage
- func VersionHasPrefix(v string) predicate.SoftwarePackage
- func VersionHasSuffix(v string) predicate.SoftwarePackage
- func VersionIn(vs ...string) predicate.SoftwarePackage
- func VersionIsNil() predicate.SoftwarePackage
- func VersionLT(v string) predicate.SoftwarePackage
- func VersionLTE(v string) predicate.SoftwarePackage
- func VersionNEQ(v string) predicate.SoftwarePackage
- func VersionNotIn(vs ...string) predicate.SoftwarePackage
- func VersionNotNil() predicate.SoftwarePackage
- type OrderOption
- func ByArch(opts ...sql.OrderTermOption) OrderOption
- func ByBranch(opts ...sql.OrderTermOption) OrderOption
- func ByBrewType(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByPackageID(opts ...sql.OrderTermOption) OrderOption
- func BySource(opts ...sql.OrderTermOption) OrderOption
- func ByVerified(opts ...sql.OrderTermOption) OrderOption
- func ByVersion(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the softwarepackage type in the database. Label = "software_package" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldPackageID holds the string denoting the package_id field in the database. FieldPackageID = "package_id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldVersion holds the string denoting the version field in the database. FieldVersion = "version" // FieldBranch holds the string denoting the branch field in the database. FieldBranch = "branch" // FieldArch holds the string denoting the arch field in the database. FieldArch = "arch" // FieldBrewType holds the string denoting the brew_type field in the database. FieldBrewType = "brew_type" // FieldVerified holds the string denoting the verified field in the database. FieldVerified = "verified" // FieldSource holds the string denoting the source field in the database. FieldSource = "source" // Table holds the table name of the softwarepackage in the database. Table = "software_packages" )
Variables ¶
var Columns = []string{ FieldID, FieldPackageID, FieldName, FieldVersion, FieldBranch, FieldArch, FieldBrewType, FieldVerified, FieldSource, }
Columns holds all SQL columns for softwarepackage fields.
var ( // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
Functions ¶
func And ¶
func And(predicates ...predicate.SoftwarePackage) predicate.SoftwarePackage
And groups predicates with the AND operator between them.
func Arch ¶
func Arch(v string) predicate.SoftwarePackage
Arch applies equality check predicate on the "arch" field. It's identical to ArchEQ.
func ArchContains ¶
func ArchContains(v string) predicate.SoftwarePackage
ArchContains applies the Contains predicate on the "arch" field.
func ArchContainsFold ¶
func ArchContainsFold(v string) predicate.SoftwarePackage
ArchContainsFold applies the ContainsFold predicate on the "arch" field.
func ArchEQ ¶
func ArchEQ(v string) predicate.SoftwarePackage
ArchEQ applies the EQ predicate on the "arch" field.
func ArchEqualFold ¶
func ArchEqualFold(v string) predicate.SoftwarePackage
ArchEqualFold applies the EqualFold predicate on the "arch" field.
func ArchGT ¶
func ArchGT(v string) predicate.SoftwarePackage
ArchGT applies the GT predicate on the "arch" field.
func ArchGTE ¶
func ArchGTE(v string) predicate.SoftwarePackage
ArchGTE applies the GTE predicate on the "arch" field.
func ArchHasPrefix ¶
func ArchHasPrefix(v string) predicate.SoftwarePackage
ArchHasPrefix applies the HasPrefix predicate on the "arch" field.
func ArchHasSuffix ¶
func ArchHasSuffix(v string) predicate.SoftwarePackage
ArchHasSuffix applies the HasSuffix predicate on the "arch" field.
func ArchIn ¶
func ArchIn(vs ...string) predicate.SoftwarePackage
ArchIn applies the In predicate on the "arch" field.
func ArchIsNil ¶
func ArchIsNil() predicate.SoftwarePackage
ArchIsNil applies the IsNil predicate on the "arch" field.
func ArchLT ¶
func ArchLT(v string) predicate.SoftwarePackage
ArchLT applies the LT predicate on the "arch" field.
func ArchLTE ¶
func ArchLTE(v string) predicate.SoftwarePackage
ArchLTE applies the LTE predicate on the "arch" field.
func ArchNEQ ¶
func ArchNEQ(v string) predicate.SoftwarePackage
ArchNEQ applies the NEQ predicate on the "arch" field.
func ArchNotIn ¶
func ArchNotIn(vs ...string) predicate.SoftwarePackage
ArchNotIn applies the NotIn predicate on the "arch" field.
func ArchNotNil ¶
func ArchNotNil() predicate.SoftwarePackage
ArchNotNil applies the NotNil predicate on the "arch" field.
func Branch ¶
func Branch(v string) predicate.SoftwarePackage
Branch applies equality check predicate on the "branch" field. It's identical to BranchEQ.
func BranchContains ¶
func BranchContains(v string) predicate.SoftwarePackage
BranchContains applies the Contains predicate on the "branch" field.
func BranchContainsFold ¶
func BranchContainsFold(v string) predicate.SoftwarePackage
BranchContainsFold applies the ContainsFold predicate on the "branch" field.
func BranchEQ ¶
func BranchEQ(v string) predicate.SoftwarePackage
BranchEQ applies the EQ predicate on the "branch" field.
func BranchEqualFold ¶
func BranchEqualFold(v string) predicate.SoftwarePackage
BranchEqualFold applies the EqualFold predicate on the "branch" field.
func BranchGT ¶
func BranchGT(v string) predicate.SoftwarePackage
BranchGT applies the GT predicate on the "branch" field.
func BranchGTE ¶
func BranchGTE(v string) predicate.SoftwarePackage
BranchGTE applies the GTE predicate on the "branch" field.
func BranchHasPrefix ¶
func BranchHasPrefix(v string) predicate.SoftwarePackage
BranchHasPrefix applies the HasPrefix predicate on the "branch" field.
func BranchHasSuffix ¶
func BranchHasSuffix(v string) predicate.SoftwarePackage
BranchHasSuffix applies the HasSuffix predicate on the "branch" field.
func BranchIn ¶
func BranchIn(vs ...string) predicate.SoftwarePackage
BranchIn applies the In predicate on the "branch" field.
func BranchIsNil ¶
func BranchIsNil() predicate.SoftwarePackage
BranchIsNil applies the IsNil predicate on the "branch" field.
func BranchLT ¶
func BranchLT(v string) predicate.SoftwarePackage
BranchLT applies the LT predicate on the "branch" field.
func BranchLTE ¶
func BranchLTE(v string) predicate.SoftwarePackage
BranchLTE applies the LTE predicate on the "branch" field.
func BranchNEQ ¶
func BranchNEQ(v string) predicate.SoftwarePackage
BranchNEQ applies the NEQ predicate on the "branch" field.
func BranchNotIn ¶
func BranchNotIn(vs ...string) predicate.SoftwarePackage
BranchNotIn applies the NotIn predicate on the "branch" field.
func BranchNotNil ¶
func BranchNotNil() predicate.SoftwarePackage
BranchNotNil applies the NotNil predicate on the "branch" field.
func BrewType ¶
func BrewType(v string) predicate.SoftwarePackage
BrewType applies equality check predicate on the "brew_type" field. It's identical to BrewTypeEQ.
func BrewTypeContains ¶
func BrewTypeContains(v string) predicate.SoftwarePackage
BrewTypeContains applies the Contains predicate on the "brew_type" field.
func BrewTypeContainsFold ¶
func BrewTypeContainsFold(v string) predicate.SoftwarePackage
BrewTypeContainsFold applies the ContainsFold predicate on the "brew_type" field.
func BrewTypeEQ ¶
func BrewTypeEQ(v string) predicate.SoftwarePackage
BrewTypeEQ applies the EQ predicate on the "brew_type" field.
func BrewTypeEqualFold ¶
func BrewTypeEqualFold(v string) predicate.SoftwarePackage
BrewTypeEqualFold applies the EqualFold predicate on the "brew_type" field.
func BrewTypeGT ¶
func BrewTypeGT(v string) predicate.SoftwarePackage
BrewTypeGT applies the GT predicate on the "brew_type" field.
func BrewTypeGTE ¶
func BrewTypeGTE(v string) predicate.SoftwarePackage
BrewTypeGTE applies the GTE predicate on the "brew_type" field.
func BrewTypeHasPrefix ¶
func BrewTypeHasPrefix(v string) predicate.SoftwarePackage
BrewTypeHasPrefix applies the HasPrefix predicate on the "brew_type" field.
func BrewTypeHasSuffix ¶
func BrewTypeHasSuffix(v string) predicate.SoftwarePackage
BrewTypeHasSuffix applies the HasSuffix predicate on the "brew_type" field.
func BrewTypeIn ¶
func BrewTypeIn(vs ...string) predicate.SoftwarePackage
BrewTypeIn applies the In predicate on the "brew_type" field.
func BrewTypeIsNil ¶
func BrewTypeIsNil() predicate.SoftwarePackage
BrewTypeIsNil applies the IsNil predicate on the "brew_type" field.
func BrewTypeLT ¶
func BrewTypeLT(v string) predicate.SoftwarePackage
BrewTypeLT applies the LT predicate on the "brew_type" field.
func BrewTypeLTE ¶
func BrewTypeLTE(v string) predicate.SoftwarePackage
BrewTypeLTE applies the LTE predicate on the "brew_type" field.
func BrewTypeNEQ ¶
func BrewTypeNEQ(v string) predicate.SoftwarePackage
BrewTypeNEQ applies the NEQ predicate on the "brew_type" field.
func BrewTypeNotIn ¶
func BrewTypeNotIn(vs ...string) predicate.SoftwarePackage
BrewTypeNotIn applies the NotIn predicate on the "brew_type" field.
func BrewTypeNotNil ¶
func BrewTypeNotNil() predicate.SoftwarePackage
BrewTypeNotNil applies the NotNil predicate on the "brew_type" field.
func ID ¶
func ID(id uuid.UUID) predicate.SoftwarePackage
ID filters vertices based on their ID field.
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.SoftwarePackage
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.SoftwarePackage
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.SoftwarePackage
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.SoftwarePackage
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.SoftwarePackage
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.SoftwarePackage
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.SoftwarePackage
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.SoftwarePackage
IDNotIn applies the NotIn predicate on the ID field.
func Name ¶
func Name(v string) predicate.SoftwarePackage
Name applies equality check predicate on the "name" field. It's identical to NameEQ.
func NameContains ¶
func NameContains(v string) predicate.SoftwarePackage
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
func NameContainsFold(v string) predicate.SoftwarePackage
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEQ ¶
func NameEQ(v string) predicate.SoftwarePackage
NameEQ applies the EQ predicate on the "name" field.
func NameEqualFold ¶
func NameEqualFold(v string) predicate.SoftwarePackage
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameGT ¶
func NameGT(v string) predicate.SoftwarePackage
NameGT applies the GT predicate on the "name" field.
func NameGTE ¶
func NameGTE(v string) predicate.SoftwarePackage
NameGTE applies the GTE predicate on the "name" field.
func NameHasPrefix ¶
func NameHasPrefix(v string) predicate.SoftwarePackage
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
func NameHasSuffix(v string) predicate.SoftwarePackage
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameIn ¶
func NameIn(vs ...string) predicate.SoftwarePackage
NameIn applies the In predicate on the "name" field.
func NameLT ¶
func NameLT(v string) predicate.SoftwarePackage
NameLT applies the LT predicate on the "name" field.
func NameLTE ¶
func NameLTE(v string) predicate.SoftwarePackage
NameLTE applies the LTE predicate on the "name" field.
func NameNEQ ¶
func NameNEQ(v string) predicate.SoftwarePackage
NameNEQ applies the NEQ predicate on the "name" field.
func NameNotIn ¶
func NameNotIn(vs ...string) predicate.SoftwarePackage
NameNotIn applies the NotIn predicate on the "name" field.
func Not ¶
func Not(p predicate.SoftwarePackage) predicate.SoftwarePackage
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.SoftwarePackage) predicate.SoftwarePackage
Or groups predicates with the OR operator between them.
func PackageID ¶
func PackageID(v string) predicate.SoftwarePackage
PackageID applies equality check predicate on the "package_id" field. It's identical to PackageIDEQ.
func PackageIDContains ¶
func PackageIDContains(v string) predicate.SoftwarePackage
PackageIDContains applies the Contains predicate on the "package_id" field.
func PackageIDContainsFold ¶
func PackageIDContainsFold(v string) predicate.SoftwarePackage
PackageIDContainsFold applies the ContainsFold predicate on the "package_id" field.
func PackageIDEQ ¶
func PackageIDEQ(v string) predicate.SoftwarePackage
PackageIDEQ applies the EQ predicate on the "package_id" field.
func PackageIDEqualFold ¶
func PackageIDEqualFold(v string) predicate.SoftwarePackage
PackageIDEqualFold applies the EqualFold predicate on the "package_id" field.
func PackageIDGT ¶
func PackageIDGT(v string) predicate.SoftwarePackage
PackageIDGT applies the GT predicate on the "package_id" field.
func PackageIDGTE ¶
func PackageIDGTE(v string) predicate.SoftwarePackage
PackageIDGTE applies the GTE predicate on the "package_id" field.
func PackageIDHasPrefix ¶
func PackageIDHasPrefix(v string) predicate.SoftwarePackage
PackageIDHasPrefix applies the HasPrefix predicate on the "package_id" field.
func PackageIDHasSuffix ¶
func PackageIDHasSuffix(v string) predicate.SoftwarePackage
PackageIDHasSuffix applies the HasSuffix predicate on the "package_id" field.
func PackageIDIn ¶
func PackageIDIn(vs ...string) predicate.SoftwarePackage
PackageIDIn applies the In predicate on the "package_id" field.
func PackageIDLT ¶
func PackageIDLT(v string) predicate.SoftwarePackage
PackageIDLT applies the LT predicate on the "package_id" field.
func PackageIDLTE ¶
func PackageIDLTE(v string) predicate.SoftwarePackage
PackageIDLTE applies the LTE predicate on the "package_id" field.
func PackageIDNEQ ¶
func PackageIDNEQ(v string) predicate.SoftwarePackage
PackageIDNEQ applies the NEQ predicate on the "package_id" field.
func PackageIDNotIn ¶
func PackageIDNotIn(vs ...string) predicate.SoftwarePackage
PackageIDNotIn applies the NotIn predicate on the "package_id" field.
func Source ¶
func Source(v string) predicate.SoftwarePackage
Source applies equality check predicate on the "source" field. It's identical to SourceEQ.
func SourceContains ¶
func SourceContains(v string) predicate.SoftwarePackage
SourceContains applies the Contains predicate on the "source" field.
func SourceContainsFold ¶
func SourceContainsFold(v string) predicate.SoftwarePackage
SourceContainsFold applies the ContainsFold predicate on the "source" field.
func SourceEQ ¶
func SourceEQ(v string) predicate.SoftwarePackage
SourceEQ applies the EQ predicate on the "source" field.
func SourceEqualFold ¶
func SourceEqualFold(v string) predicate.SoftwarePackage
SourceEqualFold applies the EqualFold predicate on the "source" field.
func SourceGT ¶
func SourceGT(v string) predicate.SoftwarePackage
SourceGT applies the GT predicate on the "source" field.
func SourceGTE ¶
func SourceGTE(v string) predicate.SoftwarePackage
SourceGTE applies the GTE predicate on the "source" field.
func SourceHasPrefix ¶
func SourceHasPrefix(v string) predicate.SoftwarePackage
SourceHasPrefix applies the HasPrefix predicate on the "source" field.
func SourceHasSuffix ¶
func SourceHasSuffix(v string) predicate.SoftwarePackage
SourceHasSuffix applies the HasSuffix predicate on the "source" field.
func SourceIn ¶
func SourceIn(vs ...string) predicate.SoftwarePackage
SourceIn applies the In predicate on the "source" field.
func SourceLT ¶
func SourceLT(v string) predicate.SoftwarePackage
SourceLT applies the LT predicate on the "source" field.
func SourceLTE ¶
func SourceLTE(v string) predicate.SoftwarePackage
SourceLTE applies the LTE predicate on the "source" field.
func SourceNEQ ¶
func SourceNEQ(v string) predicate.SoftwarePackage
SourceNEQ applies the NEQ predicate on the "source" field.
func SourceNotIn ¶
func SourceNotIn(vs ...string) predicate.SoftwarePackage
SourceNotIn applies the NotIn predicate on the "source" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Verified ¶
func Verified(v bool) predicate.SoftwarePackage
Verified applies equality check predicate on the "verified" field. It's identical to VerifiedEQ.
func VerifiedEQ ¶
func VerifiedEQ(v bool) predicate.SoftwarePackage
VerifiedEQ applies the EQ predicate on the "verified" field.
func VerifiedIsNil ¶
func VerifiedIsNil() predicate.SoftwarePackage
VerifiedIsNil applies the IsNil predicate on the "verified" field.
func VerifiedNEQ ¶
func VerifiedNEQ(v bool) predicate.SoftwarePackage
VerifiedNEQ applies the NEQ predicate on the "verified" field.
func VerifiedNotNil ¶
func VerifiedNotNil() predicate.SoftwarePackage
VerifiedNotNil applies the NotNil predicate on the "verified" field.
func Version ¶
func Version(v string) predicate.SoftwarePackage
Version applies equality check predicate on the "version" field. It's identical to VersionEQ.
func VersionContains ¶
func VersionContains(v string) predicate.SoftwarePackage
VersionContains applies the Contains predicate on the "version" field.
func VersionContainsFold ¶
func VersionContainsFold(v string) predicate.SoftwarePackage
VersionContainsFold applies the ContainsFold predicate on the "version" field.
func VersionEQ ¶
func VersionEQ(v string) predicate.SoftwarePackage
VersionEQ applies the EQ predicate on the "version" field.
func VersionEqualFold ¶
func VersionEqualFold(v string) predicate.SoftwarePackage
VersionEqualFold applies the EqualFold predicate on the "version" field.
func VersionGT ¶
func VersionGT(v string) predicate.SoftwarePackage
VersionGT applies the GT predicate on the "version" field.
func VersionGTE ¶
func VersionGTE(v string) predicate.SoftwarePackage
VersionGTE applies the GTE predicate on the "version" field.
func VersionHasPrefix ¶
func VersionHasPrefix(v string) predicate.SoftwarePackage
VersionHasPrefix applies the HasPrefix predicate on the "version" field.
func VersionHasSuffix ¶
func VersionHasSuffix(v string) predicate.SoftwarePackage
VersionHasSuffix applies the HasSuffix predicate on the "version" field.
func VersionIn ¶
func VersionIn(vs ...string) predicate.SoftwarePackage
VersionIn applies the In predicate on the "version" field.
func VersionIsNil ¶
func VersionIsNil() predicate.SoftwarePackage
VersionIsNil applies the IsNil predicate on the "version" field.
func VersionLT ¶
func VersionLT(v string) predicate.SoftwarePackage
VersionLT applies the LT predicate on the "version" field.
func VersionLTE ¶
func VersionLTE(v string) predicate.SoftwarePackage
VersionLTE applies the LTE predicate on the "version" field.
func VersionNEQ ¶
func VersionNEQ(v string) predicate.SoftwarePackage
VersionNEQ applies the NEQ predicate on the "version" field.
func VersionNotIn ¶
func VersionNotIn(vs ...string) predicate.SoftwarePackage
VersionNotIn applies the NotIn predicate on the "version" field.
func VersionNotNil ¶
func VersionNotNil() predicate.SoftwarePackage
VersionNotNil applies the NotNil predicate on the "version" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the SoftwarePackage queries.
func ByArch ¶
func ByArch(opts ...sql.OrderTermOption) OrderOption
ByArch orders the results by the arch field.
func ByBranch ¶
func ByBranch(opts ...sql.OrderTermOption) OrderOption
ByBranch orders the results by the branch field.
func ByBrewType ¶
func ByBrewType(opts ...sql.OrderTermOption) OrderOption
ByBrewType orders the results by the brew_type field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByPackageID ¶
func ByPackageID(opts ...sql.OrderTermOption) OrderOption
ByPackageID orders the results by the package_id field.
func BySource ¶
func BySource(opts ...sql.OrderTermOption) OrderOption
BySource orders the results by the source field.
func ByVerified ¶
func ByVerified(opts ...sql.OrderTermOption) OrderOption
ByVerified orders the results by the verified field.
func ByVersion ¶
func ByVersion(opts ...sql.OrderTermOption) OrderOption
ByVersion orders the results by the version field.